@@ -1,4 +1,4 @@
-<?php // $Id: cron.php,v 1.126.2.16 2008/12/29 19:58:05 skodak Exp $
+<?php // $Id: cron.php,v 1.126.2.20 2010/03/04 17:06:19 mjollnir_ Exp $
 
 /// This script looks through all the module directories for cron.php files
 /// and runs them.  These files can contain cleanup functions, email functions
@@ -223,6 +223,9 @@
     grade_cron();
     mtrace('done.');
 
+    mtrace('Starting processing the event queue...');
+    events_cron();
+    mtrace('done.');
 
 /// Run all core cron jobs, but not every time since they aren't too important.
 /// These don't have a timer to reduce load, so we'll use a random number 
@@ -350,7 +353,7 @@
                                                 p.id as prefid 
                                         FROM {$CFG->prefix}user u 
                                              JOIN {$CFG->prefix}user_preferences p ON u.id=p.userid
-                                        WHERE p.name='create_password' AND p.value=1 AND u.email !='' ");
+                                        WHERE p.name='create_password' AND p.value='1' AND u.email !='' ");
 
             foreach ($newusers as $newuserid => $newuser) {
                 $newuser->emailstop = 0; // send email regardless
@@ -425,6 +428,23 @@
         }
     }
 
+/// Run the auth cron, if any
+/// before enrolments because it might add users that will be needed in enrol plugins
+    $auths = get_enabled_auth_plugins();
+
+    mtrace("Running auth crons if required...");
+    foreach ($auths as $auth) {
+        $authplugin = get_auth_plugin($auth);
+        if (method_exists($authplugin, 'cron')) {
+            mtrace("Running cron for auth/$auth...");
+            $authplugin->cron();
+            if (!empty($authplugin->log)) {
+                mtrace($authplugin->log);
+            }
+        }
+        unset($authplugin);
+    }
+
 /// Run the enrolment cron, if any
     if (!($plugins = explode(',', $CFG->enrol_plugins_enabled))) {
         $plugins = array($CFG->enrol);
@@ -441,22 +461,6 @@
         unset($enrol);
     }
 
-/// Run the auth cron, if any
-    $auths = get_enabled_auth_plugins();
-
-    mtrace("Running auth crons if required...");
-    foreach ($auths as $auth) {
-        $authplugin = get_auth_plugin($auth);
-        if (method_exists($authplugin, 'cron')) {
-            mtrace("Running cron for auth/$auth...");
-            $authplugin->cron();
-            if (!empty($authplugin->log)) {
-                mtrace($authplugin->log);
-            }
-        }
-        unset($authplugin);
-    }
-
     if (!empty($CFG->enablestats) and empty($CFG->disablestatsprocessing)) {
         require_once($CFG->dirroot.'/lib/statslib.php');
         // check we're not before our runtime
@@ -480,44 +484,44 @@
 
     // run gradebook import/export/report cron
     if ($gradeimports = get_list_of_plugins('grade/import')) {
-        foreach ($gradeimports as $gradeimport) {           
+        foreach ($gradeimports as $gradeimport) {
             if (file_exists($CFG->dirroot.'/grade/import/'.$gradeimport.'/lib.php')) {
                 require_once($CFG->dirroot.'/grade/import/'.$gradeimport.'/lib.php');
-                $cron_function = 'grade_import_'.$gradeimport.'_cron';                                    
+                $cron_function = 'grade_import_'.$gradeimport.'_cron';
                 if (function_exists($cron_function)) {
                     mtrace("Processing gradebook import function $cron_function ...", '');
-                    $cron_function;  
+                    $cron_function();
                 }
             }
-        }      
+        }
     }
 
     if ($gradeexports = get_list_of_plugins('grade/export')) {
-        foreach ($gradeexports as $gradeexport) {           
+        foreach ($gradeexports as $gradeexport) {
             if (file_exists($CFG->dirroot.'/grade/export/'.$gradeexport.'/lib.php')) {
                 require_once($CFG->dirroot.'/grade/export/'.$gradeexport.'/lib.php');
-                $cron_function = 'grade_export_'.$gradeexport.'_cron';                                    
+                $cron_function = 'grade_export_'.$gradeexport.'_cron';
                 if (function_exists($cron_function)) {
                     mtrace("Processing gradebook export function $cron_function ...", '');
-                    $cron_function;  
+                    $cron_function();
                 }
             }
         }
     }
 
     if ($gradereports = get_list_of_plugins('grade/report')) {
-        foreach ($gradereports as $gradereport) {           
+        foreach ($gradereports as $gradereport) {
             if (file_exists($CFG->dirroot.'/grade/report/'.$gradereport.'/lib.php')) {
                 require_once($CFG->dirroot.'/grade/report/'.$gradereport.'/lib.php');
-                $cron_function = 'grade_report_'.$gradereport.'_cron';                                    
+                $cron_function = 'grade_report_'.$gradereport.'_cron';
                 if (function_exists($cron_function)) {
                     mtrace("Processing gradebook report function $cron_function ...", '');
-                    $cron_function;  
+                    $cron_function();
                 }
             }
         }
     }
-    
+
     // run any customized cronjobs, if any
     // looking for functions in lib/local/cron.php
     if (file_exists($CFG->dirroot.'/local/cron.php')) {
