@@ -1,4 +1,4 @@
-<?php // $Id: assign.php,v 1.63.2.15 2008/12/11 09:21:52 tjhunt Exp $
+<?php // $Id: assign.php,v 1.63.2.17 2010/02/12 16:33:54 sam_marshall Exp $
       // Script to assign users to contexts
 
     require_once('../../config.php');
@@ -325,7 +325,7 @@
                 if ($validroleids) {
                     $roleids =  '('.implode(',', $validroleids).')';
 
-                    $select = " SELECT u.id, u.firstname, u.lastname, u.email";
+                    $select = " SELECT DISTINCT u.id, u.firstname, u.lastname, u.email";
                     $countselect = "SELECT COUNT(u.id)";
                     $from   = " FROM {$CFG->prefix}user u
                                 INNER JOIN {$CFG->prefix}role_assignments ra ON ra.userid = u.id
@@ -395,6 +395,12 @@
             notify($msg);
             print_simple_box_end();
         }
+		
+		//Back to Assign Roles button
+		echo "<br/>";
+		echo "<div class='continuebutton'>";
+		print_single_button('assign.php', array('contextid' => $contextid), get_string('assignrolesin', 'role', print_context_name($context)));
+		echo "</div>";
 
     } else {   // Print overview table
 
@@ -429,7 +435,8 @@
                 $rolehodlernames[$roleid] = '';
             }
         }
-
+		
+		
         // Print overview table
         $table->tablealign = 'center';
         $table->cellpadding = 5;
@@ -452,10 +459,14 @@
             }
             $table->data[] = $row;
         }
-
         print_table($table);
+		
+	   //Continue to Course Button
+	   echo "<br/>";
+	   echo "<div class='continuebutton'>";
+	   print_single_button($CFG->wwwroot.'/course/view.php', array('id' => $courseid), get_string('continuetocourse'));
+	   echo "</div>";
     }
-
+	
     print_footer($course);
-
 ?>
