@@ -1,4 +1,4 @@
-<?PHP // $Id: config-dist.php,v 1.103.2.4 2008/06/30 15:00:25 thepurpleblob Exp $
+<?PHP // $Id: config-dist.php,v 1.103.2.15 2010/04/02 09:33:11 mudrd8mz Exp $
 ///////////////////////////////////////////////////////////////////////////
 //                                                                       //
 // Moodle configuration file                                             //
@@ -28,6 +28,7 @@
 //                                                                       //
 ///////////////////////////////////////////////////////////////////////////
 unset($CFG);  // Ignore this line
+$CFG = new stdClass();
 
 //=========================================================================
 // 1. DATABASE SETUP
@@ -59,6 +60,27 @@ $CFG->dbpersist = false;         // Should database connections be reused?
                  // "true" can improve performance sometimes
 
 
+//=========================================================================
+// 1.5. SECRET PASSWORD SALT
+//=========================================================================
+// User password salt is very important security feature, it is created
+// automatically in installer, you have to uncomment and modify value
+// on the next line if you are creating config.php manually.
+//
+// $CFG->passwordsaltmain = 'a_very_long_random_string_of_characters#@6&*1';
+//
+// After changing the main salt you have to copy old value into one
+// of the following settings - this allows migration to the new salt
+// during the next login of each user.
+//
+// $CFG->passwordsaltalt1 = '';
+// $CFG->passwordsaltalt2 = '';
+// $CFG->passwordsaltalt3 = '';
+// ....
+// $CFG->passwordsaltalt19 = '';
+// $CFG->passwordsaltalt20 = '';
+
+
 //=========================================================================
 // 2. WEB SITE LOCATION
 //=========================================================================
@@ -76,7 +98,7 @@ $CFG->wwwroot   = 'http://example.com/moodle';
 // Next, specify the full OS directory path to this same location
 // Make sure the upper/lower case is correct.  Some examples:
 //
-//    $CFG->dirroot = 'c:\program files\easyphp\www\moodle';    // Windows
+//    $CFG->dirroot = 'C:\program files\easyphp\www\moodle';    // Windows
 //    $CFG->dirroot = '/var/www/html/moodle';     // Redhat Linux
 //    $CFG->dirroot = '/home/example/public_html/moodle'; // Cpanel host
 
@@ -131,6 +153,11 @@ $CFG->admin = 'admin';
 //
 // These are additional tweaks for which no GUI exists in Moodle yet.
 //
+// Starting in PHP 5.3 administrators should specify default timezone
+// in PHP.ini, you can also specify it here if needed.
+// See details at: http://php.net/manual/en/function.date-default-timezone-set.php
+// List of time zones at: http://php.net/manual/en/timezones.php
+//     date_default_timezone_set('Australia/Perth');
 //
 // Change the key pair lifetime for Moodle Networking
 // The default is 28 days. You would only want to change this if the key
@@ -143,6 +170,29 @@ $CFG->admin = 'admin';
 // Useful for webhost operators who have alternate methods of backups
 //      $CFG->disablescheduledbackups = true;
 //
+// Allow user passwords to be included in backup files. Very dangerous
+// setting as far as it publishes password hashes that can be unencrypted
+// if the backup file is publicy available. Use it only if you can guarantee
+// that all your backup files remain only privacy available and are never
+// shared out from your site/institution!
+//      $CFG->includeuserpasswordsinbackup = true;
+//
+// Completely disable user creation when restoring a course, bypassing any
+// permissions granted via roles and capabilities. Enabling this setting
+// results in the restore process stopping when a user attempts to restore a
+// course requiring users to be created.
+//     $CFG->disableusercreationonrestore = true;
+//
+// Modify the restore process in order to force the "user checks" to assume
+// that the backup originated from a different site, so detection of matching
+// users is performed with different (more "relaxed") rules. Note that this is
+// only useful if the backup file has been created using Moodle < 1.9.4 and the
+// site has been rebuilt from scratch using backup files (not the best way btw).
+// If you obtain user conflicts on restore, rather than enabling this setting
+// permanently, try restoring the backup on a different site, back it up again
+// and then restore on the target server.
+//    $CFG->forcedifferentsitecheckingusersonrestore = true;
+//
 // Prevent stats processing and hide the GUI
 //      $CFG->disablestatsprocessing = true;
 //
@@ -178,7 +228,13 @@ $CFG->admin = 'admin';
 // This setting will prevent the 'My Courses' page being displayed when a student
 // logs in. The site front page will always show the same (logged-out) view.
 //     $CFG->disablemycourses = true;
-// 
+//
+// Enable this option if you need fully working default frontpage role,
+// please note it might cause serious memory and performance issues,
+// also there should not be any negative capabilities in default
+// frontpage role (MDL-19039).
+//     $CFG->fullusersbycapabilityonfrontpage = true;
+//
 // If this setting is set to true, then Moodle will track the IP of the 
 // current user to make sure it hasn't changed during a session.  This 
 // will prevent the possibility of sessions being hijacked via XSS, but it 
@@ -259,6 +315,9 @@ $CFG->admin = 'admin';
 // The following setting will log every database query to a table called adodb_logsql.
 // Use this setting on a development server only, the table grows quickly!
 //     $CFG->logsql = true;
+// By default, only queries that take longer than 0.05 seconds are logged. To change that,
+// set the following variable. For example, to lot all queries:
+//     $CFG->logsqlmintime = 0.0;
 //
 // The following setting will turn on username logging into Apache log. For full details regarding setting
 // up of this function please refer to the install section of the document.
@@ -305,6 +364,8 @@ $CFG->admin = 'admin';
 // When working with production data on test servers, no emails should ever be send to real users
 // $CFG->noemailever = true;
 //
+// Divert all outgoing emails to this address to test and debug emailing features
+// $CFG->divertallemailsto = 'root@localhost.local';
 //
 //=========================================================================
 // ALL DONE!  To continue installation, visit your main page with a browser
