@@ -1,4 +1,4 @@
-<?php /// $Id: install.php,v 1.80.2.17 2008/11/19 09:46:38 skodak Exp $
+<?php /// $Id: install.php,v 1.80.2.21 2010/02/21 14:46:49 poltawski Exp $
       /// install.php - helps admin user to create a config.php file
 
 /// If config.php exists already then we are not needed.
@@ -448,7 +448,8 @@ if ($INSTALL['stage'] == ENVIRONMENT) {
     $dbconnected = $db->Connect($INSTALL['dbhost'],$INSTALL['dbuser'],$INSTALL['dbpass'],$INSTALL['dbname']);
     error_reporting(7);  // Show errors
     if ($dbconnected) {
-    /// Execute environment check, printing results
+    /// Execute environment check, not printing results
+        @remove_dir($INSTALL['dataroot'] . '/environment'); /// Always delete downloaded env. info to force use of the released one. MDL-9796
         if (!check_moodle_environment($INSTALL['release'], $environment_results, false)) {
              $nextstage = ENVIRONMENT;
         }
@@ -532,6 +533,7 @@ if ($nextstage == SAVE) {
     $str .= 'unset($CFG);'."\r\n";
     $str .= "\r\n";
 
+    $str .= '$CFG = new stdClass();'."\r\n";
     $str .= '$CFG->dbtype    = \''.$INSTALL['dbtype']."';\r\n";
     $str .= '$CFG->dbhost    = \''.addslashes($INSTALL['dbhost'])."';\r\n";
     if (!empty($INSTALL['dbname'])) {
@@ -553,6 +555,9 @@ if ($nextstage == SAVE) {
     $str .= '$CFG->directorypermissions = 00777;  // try 02777 on a server in Safe Mode'."\r\n";
     $str .= "\r\n";
 
+    $str .= '$CFG->passwordsaltmain = \''.addsingleslashes(complex_random_string()).'\';'."\r\n";
+    $str .= "\r\n";
+
     $str .= 'require_once("$CFG->dirroot/lib/setup.php");'."\r\n";
     $str .= '// MAKE SURE WHEN YOU EDIT THIS FILE THAT THERE ARE NO SPACES, BLANK LINES,'."\r\n";
     $str .= '// RETURNS, OR ANYTHING ELSE AFTER THE TWO CHARACTERS ON THE NEXT LINE.'."\r\n";
@@ -907,6 +912,7 @@ function form_table($nextstage = WELCOME, $formaction = "install.php") {
                     error_reporting(7);  // Show errors
                     if ($dbconnected) {
                     /// Execute environment check, printing results
+                        @remove_dir($INSTALL['dataroot'] . '/environment'); /// Always delete downloaded env. info to force use of the released one. MDL-9796
                         check_moodle_environment($INSTALL['release'], $environment_results, true);
                     } else {
                     /// We never should reach this because DB has been tested before arriving here
@@ -1080,7 +1086,7 @@ function check_memory_limit() {
     }
 
     /// Otherwise, see if we can change it ourselves
-    @ini_set('memory_limit', '40M');
+    raise_memory_limit('40M');
     return ((int)str_replace('M', '', get_memory_limit()) >= 40);
 }
 
