@@ -1,4 +1,4 @@
-<?PHP // $Id: grades.php,v 1.111.2.60 2009/01/08 08:19:42 nicolasconnault Exp $
+<?PHP // $Id: grades.php,v 1.111.2.70 2010/04/02 12:01:56 wildgirl Exp $
       // grades.php - created with Moodle 1.7 beta + (2006101003)
 
 
@@ -11,6 +11,8 @@ $string['addgradeletter'] = 'Add a grade letter';
 $string['addidnumbers'] = 'Add id numbers';
 $string['additem'] = 'Add grade item';
 $string['addoutcomeitem'] = 'Add outcome item';
+$string['addoutcome'] = 'Add an outcome';
+$string['addscale'] = 'Add a scale';
 $string['aggregateextracreditmean'] = 'Mean of grades (with extra credits)';
 $string['aggregatemean'] = 'Mean of grades';
 $string['aggregatemedian'] = 'Median of grades';
@@ -22,7 +24,7 @@ $string['aggregateonlygradedhelp'] = 'Nonexistent grades are either treated as m
 $string['aggregateoutcomes'] = 'Include outcomes in aggregation';
 $string['aggregateoutcomeshelp'] = 'Including outcomes in aggregation may not lead to the desired overall grade, so you have the option to include or leave them out.';
 $string['aggregatesubcats'] = 'Aggregate including subcategories';
-$string['aggregatesubcatshelp'] = 'The aggregation is usually done only with immediate children, it is also possible to aggregate grades in all subcategories excluding other aggregated grades.';
+$string['aggregatesubcatshelp'] = 'The aggregation is usually done only with immediate children, it is also possible to aggregate including individual grades in all subcategories excluding other aggregated grades.';
 $string['aggregatesum'] = 'Sum of grades';
 $string['aggregatesonly'] = 'Aggregates only';
 $string['aggregateweightedmean'] = 'Weighted mean of grades';
@@ -37,6 +39,8 @@ $string['aggregationcoefweight'] = 'Item weight';
 $string['aggregationcoefweighthelp'] = 'Weight applied to all grades in this grade item during aggregation with other grade items.';
 $string['aggregationhelp'] = 'Strategy used to aggregate grades across all students in a course.';
 $string['aggregationposition'] = 'Aggregation position';
+$string['aggregationsvisible'] = 'Available aggregation types';
+$string['aggregationsvisiblehelp'] = 'Select all aggregation types that should be available. Hold down the Ctrl key to select multiple items.';
 $string['aggregationview'] = 'Aggregation view';
 $string['allgrades'] = 'All grades by category';
 $string['allstudents'] = 'All students';
@@ -48,14 +52,18 @@ $string['averagesdecimalpoints'] = 'Decimals in column averages';
 $string['averagesdisplaytype'] = 'Column averages display type';
 $string['backupwithoutgradebook'] = 'Backup does not contain Gradebook configuration';
 $string['badgrade'] = 'Supplied grade is invalid';
+$string['badlyformattedscale'] = 'Please enter a comma-separated list of values (at least two values required).';
 $string['baduser'] = 'Supplied user is invalid';
 $string['bonuspoints'] = 'Bonus points';
+$string['combo'] = 'Tabs and Dropdown menu';
 $string['bulkcheckboxes'] = 'Bulk checkboxes';
+$string['calculatedgrade'] = 'Calculated grade';
 $string['calculation'] = 'Calculation';
 $string['calculationadd'] = 'Add calculation';
 $string['calculationedit'] = 'Edit calculation';
 $string['calculationview'] = 'View calculation';
 $string['calculationsaved'] = 'Calculation saved';
+$string['cannotaccessgroup'] = 'Can not access grades of selected group, sorry.';
 $string['categories'] = 'Categories';
 $string['categoriesanditems'] = 'Categories and items';
 $string['categoriesedit'] = 'Edit categories and items';
@@ -63,6 +71,7 @@ $string['category'] = 'Category';
 $string['categoryedit'] = 'Edit category';
 $string['categoryname'] = 'Category name';
 $string['categorytotal'] = 'Category total';
+$string['categorytotalfull'] = '$a->category total';
 $string['changereportdefaults'] = 'Change report defaults';
 $string['changedefaults'] = 'Change defaults';
 $string['choosecategory'] = 'Select category';
@@ -77,6 +86,7 @@ $string['configcoursegradedisplaytype'] = 'Select the default display type of gr
 $string['configdecimalpoints'] = 'Specifies the number of decimal points to display for each grade. This setting may be overridden per grading item.';
 $string['configenableajax'] = 'Adds a layer of AJAX functionality to the grader report, simplifying and speeding up common operations. Depends on Javascript being switched on at the user\'s browser level.';
 $string['configenableoutcomes'] = 'Support for Outcomes (also known as Competencies, Goals, Standards or Criteria) means that we can grade things using one or more scales that are tied to outcome statements. Enabling outcomes makes such special grading possible throughout the site.';
+$string['configfixedstudents'] = 'Allows grades to scroll horizontally without losing sight of the students column, by making it static.';
 $string['configgradeboundary'] = 'A percentage boundary over which grades will be assigned a grade letter (if the Letter grade display type is used). ';
 $string['configgradedisplaytype'] = 'Specifies how to display grades in the grader and user reports. Grades may be shown as actual grades, as percentages (in reference to the minimum and maximum grades) or as letters.';
 $string['configgradeexportdisplaytype'] = 'Grades can be shown as real grades, as percentages (in reference to the minimum and maximum grades) or as letters (A, B, C etc..) during export. This can be overridden during export.';
@@ -111,17 +121,21 @@ $string['configshowuseridnumber'] = 'Whether to show user id numbers in an addit
 $string['configshowuserimage'] = 'Whether to show the user\'s profile image next to the name in the grader report.';
 $string['configstudentsperpage'] = 'The number of students to display per page in the grader report.';
 $string['configstudentsperpagedefault'] = 'The number of students to display per page in the grader report. Leave this field empty to use the site default (currently $a).';
+$string['configunlimitedgrades'] = 'By default grades are limited by the maximum and minimum values of the grade item. Enabling this setting removes this limit, and allows grades of over 100%% to be entered directly in the gradebook. It is recommended that this setting is enabled at an off-peak time, as all grades will be recalculated, which may result in a high server load.';
 $string['contract'] = 'Contract Category';
 $string['controls'] = 'Controls';
 $string['coursegradecategory'] = 'Course grade category';
 $string['coursegradedisplaytype'] = 'Course grade display type';
 $string['coursegradedisplayupdated'] = 'The course grade display type has been updated.';
 $string['coursename'] = 'Course name';
+$string['coursescales'] = 'Course scales';
 $string['coursesettings'] = 'Course settings';
+$string['coursesettingsexplanation'] = 'Course settings determine how the gradebook appears for all participants in the course.';
 $string['coursetotal'] = 'Course total';
 $string['createcategory'] = 'Create category';
 $string['createcategoryerror'] = 'Could not create a new category';
 $string['creatinggradebooksettings'] = 'Creating gradebook settings';
+$string['currentparentaggregation'] = 'Current parent aggregation';
 $string['csv'] = 'CSV';
 $string['curveto'] = 'Curve to';
 $string['decimalpoints'] = 'Overall decimal points';
@@ -133,6 +147,7 @@ $string['displaylettergrade'] = 'Display letter grades';
 $string['displaypercent'] = 'Display percents';
 $string['displaypoints'] = 'Display points';
 $string['displayweighted'] = 'Display weighted grades';
+$string['dropdown'] = 'Dropdown menu';
 $string['droplow'] = 'Drop the lowest';
 $string['droplowhelp'] = 'If set, this option will drop the X lowest grades, X being the selected value for this option.';
 $string['dropped'] = 'Dropped';
@@ -144,7 +159,10 @@ $string['editcalculation'] = 'Edit calculation';
 $string['editcalculationverbose'] = 'Edit calculation for $a->category$a->itemmodule $a->itemname';
 $string['editfeedback'] = 'Edit feedback';
 $string['editgrade'] = 'Edit grade';
+$string['editgradeletters'] = 'Edit grade letters';
+$string['editoutcome'] = 'Edit outcome';
 $string['editoutcomes'] = 'Edit outcomes';
+$string['editscale'] = 'Edit scale';
 $string['edittree'] = 'Categories and items';
 $string['editverbose'] = 'Edit $a->category$a->itemmodule $a->itemname';
 $string['enableajax'] = 'Enable AJAX';
@@ -157,6 +175,7 @@ $string['errornocalculationallowed'] = 'Calculations are not allowed for this it
 $string['errornocategorisedid'] = 'Could not get an uncategorised id!';
 $string['errornocourse'] = 'Could not get course information';
 $string['errorreprintheadersnonnumeric'] = 'Received non-numeric value for reprint-headers';
+$string['errorsavegrade'] = 'Could not save grade, sorry.';
 $string['exceptions'] = 'Exceptions';
 $string['excluded'] = 'Excluded';
 $string['excludedhelp'] = 'If -excluded- is switched on, this grade will be excluded from any aggregation performed by any parent grade item or category.';
@@ -177,12 +196,14 @@ $string['feedbackview'] = 'View feedback';
 $string['feedbacksaved'] = 'Feedback saved';
 $string['finalgrade'] = 'Final grade';
 $string['finalgradehelp'] = 'The final grade (cached) after all calculations are performed.';
+$string['fixedstudents'] = 'Static students column';
 $string['forceoff'] = 'Force: Off';
 $string['forceon'] = 'Force: On';
 $string['forelementtypes'] = ' for the selected $a';
 $string['forstudents'] = 'For students';
 $string['full'] = 'Full';
 $string['fullmode'] = 'Full view';
+$string['fullview'] = 'Full view';
 $string['generalsettings'] = 'General settings';
 $string['grade'] = 'Grade';
 $string['gradebook'] = 'Gradebook';
@@ -200,6 +221,7 @@ $string['gradeexceptions'] = 'Grade exceptions';
 $string['gradeexceptionshelp'] = 'Grade exceptions Help';
 $string['gradeexportdisplaytype'] = 'Grade export display type';
 $string['gradeexportdecimalpoints'] = 'Grade export decimal points';
+$string['gradeforstudent'] = '$a->student<br />$a->item$a->feedback';
 $string['gradehelp'] = 'Grade Help';
 $string['gradehistorylifetime'] = 'Grade history lifetime';
 $string['gradeitem'] = 'Grade item';
@@ -234,6 +256,7 @@ $string['gradessettings'] = 'Grade settings';
 $string['gradepreferences'] = 'Grade preferences';
 $string['gradepreferenceshelp'] = 'Grade preferences Help';
 $string['grades'] = 'Grades';
+$string['gradesforuser'] = 'Grades for $a->user';
 $string['gradesonly'] = 'Grades only';
 $string['gradetype'] = 'Grade type';
 $string['gradetypehelp'] = 'Specifies the type of grade used: none (no grading possible), value (enables the maximum and minimum grade settings), scale (enables the scale setting) or text (feedback only). Only value and scale grade types may be aggregated. The grade type for an activity-based grade item is set on the update activity page.';
@@ -254,6 +277,10 @@ $string['hidelocks'] = 'Hide locks';
 $string['hidenooutcomes'] = 'Show outcomes';
 $string['hidefeedback'] = 'Hide feedback';
 $string['hideranges'] = 'Hide ranges';
+$string['hidetotalifhiddenitems'] = 'Hide totals if they contain hidden items';
+$string['hidetotalifhiddenitemsdescription'] = 'Whether totals which contain hidden grade items are shown to students (calculated either excluding or including hidden items) or replaced with a hyphen.';
+$string['hidetotalshowexhiddenitems'] = 'Show totals excluding hidden items';
+$string['hidetotalshowinchiddenitems'] = 'Show totals including hidden items';
 $string['hideverbose'] = 'Hide $a->category$a->itemmodule $a->itemname';
 $string['highgradeascending'] = 'Sort by high grade ascending';
 $string['highgradedescending'] = 'Sort by high grade descending';
@@ -284,8 +311,10 @@ $string['importsuccess'] = 'Grade import success';
 $string['importxml'] = 'Import XML';
 $string['includescalesinaggregation'] = 'Include scales in aggregation';
 $string['incorrectcourseid'] = 'Course ID was incorrect';
+$string['incorrectcustomscale'] = '(Incorrect custom scale, please change.)';
 $string['incorrectminmax'] = 'The minimum must be lower than the maximum';
 $string['inherit'] = 'Inherit';
+$string['intersectioninfo'] = 'Student/Grade info';
 $string['item'] = 'Item';
 $string['iteminfo'] = 'Item info';
 $string['iteminfohelp'] = 'A space for entering information about the item. Text entered does not appear anywhere else.';
@@ -305,6 +334,7 @@ $string['letterreal'] = 'Letter (real)';
 $string['letters'] = 'Letters';
 $string['linkedactivity'] = 'Linked activity';
 $string['linkedactivityhelp'] = 'Specifies an optional activity to which this outcome item is linked. This is used to measure student performance on criteria not assessed by the activity grade.';
+$string['linktoactivity'] = 'Link to $a->name activity';
 $string['lock'] = 'Lock';
 $string['locked'] = 'Locked';
 $string['locktime'] = 'Lock after';
@@ -326,12 +356,17 @@ $string['min'] = 'Lowest';
 $string['missingscale'] = 'Scale must be selected';
 $string['mode'] = 'Mode';
 $string['morethanmax'] = 'The grade entered for $a->itemname for $a->username is more than the maximum allowed';
+$string['moveselectedto'] = 'Move selected items to';
 $string['movingelement'] = 'Moving $a';
 $string['multfactor'] = 'Multiplicator';
 $string['multfactorhelp'] = 'Factor by which all grades for this grade item will be multiplied.';
+$string['mypreferences'] = 'My preferences';
 $string['myreportpreferences'] = 'My report preferences';
+$string['navmethod'] = 'Navigation method';
 $string['neverdeletehistory'] = 'Never delete history';
 $string['newcategory'] = 'New category';
+$string['newitem'] = 'New grade item';
+$string['newoutcomeitem'] = 'New outcome item';
 $string['newuserkey'] = 'New user key';
 $string['no'] = 'No';
 $string['nocategories'] = 'Grade categories could not be added or found for this course';
@@ -442,6 +477,7 @@ $string['scalestandardhelp'] = 'A standard scale is one that is available site-w
 $string['seeallcoursegrades'] = 'See all course grades';
 $string['selectdestination'] = 'Select destination of $a';
 $string['selectalloroneuser'] = 'Select all or one user';
+$string['selectauser'] = 'Select a user';
 $string['septab'] = 'Tab';
 $string['sepcomma'] = 'Comma';
 $string['separator'] = 'Separator';
@@ -473,6 +509,7 @@ $string['showrank'] = 'Show rank';
 $string['showuseridnumber'] = 'Show user idnumber';
 $string['showuserimage'] = 'Show user profile images';
 $string['showverbose'] = 'Show $a->category$a->itemmodule $a->itemname';
+$string['simpleview'] = 'Simple view';
 $string['sitewide'] = 'Site-wide';
 $string['sort'] = 'sort';
 $string['sortasc'] = 'Sort in ascending order';
@@ -487,7 +524,10 @@ $string['studentsperpage'] = 'Students per page';
 $string['subcategory'] = 'Normal category';
 $string['submissions'] = 'Submissions';
 $string['submittedon'] = 'Submitted: $a';
+$string['switchtofullview'] = 'Switch to full view';
+$string['switchtosimpleview'] = 'Switch to simple view';
 $string['synclegacygrades'] = 'Synchronise legacy grades';
+$string['tabs'] = 'Tabs';
 $string['topcategory'] = 'Super category';
 $string['total'] = 'Total';
 $string['totalweight100'] = 'The total weight is equal to 100';
@@ -502,6 +542,7 @@ $string['updatedgradesonly'] = 'Export new or updated grades only';
 $string['uncategorised'] = 'Uncategorised';
 $string['unchangedgrade'] = 'Grade unchanged';
 $string['unenrolledusersinimport'] = 'This import included the following grades for users not currently enrolled in this course: $a';
+$string['unlimitedgrades'] = 'Unlimited grades';
 $string['unlock'] = 'Unlock';
 $string['unlockverbose'] = 'Unlock $a->category$a->itemmodule $a->itemname';
 $string['unused'] = 'Unused';
@@ -520,12 +561,17 @@ $string['useweighted'] = 'Use weighted';
 $string['verbosescales'] = 'Verbose scales';
 $string['viewbygroup'] = 'Group';
 $string['viewgrades'] = 'View grades';
+$string['warningexcludedsum'] = 'Warning: excluding of grades is not compatible with sum aggregation.';
 $string['weight'] = 'weight';
+$string['weightuc'] = 'Weight';
 $string['weightcourse'] = 'Use weighted grades for course';
 $string['weightedascending'] = 'Sort by weighted percent ascending';
 $string['weighteddescending'] = 'Sort by weighted percent descending';
 $string['weightedpct'] = 'weighted %%';
 $string['weightedpctcontribution'] = 'weighted %% contribution';
+$string['weightorextracredit'] = 'Weight or extra credit';
+$string['weights'] = 'Weights';
+$string['weightsedit'] = 'Edit weights and extra credits';
 $string['writinggradebookinfo'] = 'Writing gradebook settings';
 $string['xml'] = 'XML';
 $string['yes'] = 'Yes';
