@@ -1,4 +1,4 @@
-<?PHP // $Id: moodle.php,v 1.141.2.55 2009/01/27 06:35:44 tjhunt Exp $
+<?PHP // $Id: moodle.php,v 1.141.2.83 2010/03/22 22:10:34 stronk7 Exp $
       // moodle.php - created with Moodle 1.7 beta + (2006101003)
 
 
@@ -43,7 +43,7 @@ $string['admin'] = 'Admin';
 $string['adminbookmarks'] = 'Admin bookmarks';
 $string['adminhelpaddnewuser'] = 'To manually create a new user account';
 $string['adminhelpassignadmins'] = 'Admins can do anything and go anywhere in the site';
-$string['adminhelpassigncreators'] = 'Creators can create new courses and teach in them';
+$string['adminhelpassigncreators'] = 'Course creators can create new courses';
 $string['adminhelpassignsiteroles'] = 'Apply defined site roles to specific users';
 $string['adminhelpassignstudents'] = 'Go into a course and add students from the admin menu';
 $string['adminhelpassignteachers'] = 'Find a course then use the icon to add teachers';
@@ -159,8 +159,10 @@ $string['backuploglaststatus'] = 'Last execution log';
 $string['backuplogshelp'] = 'If enabled, then course logs will be included in automated backups';
 $string['backupmetacoursehelp'] = 'If enabled, then metacourse info (inherited enrolments) will be included in automated backups';
 $string['backupnameformat'] = '%%Y%%m%%d-%%H%%M';
-$string['backupnoneusersinfo'] = 'Notice: You have selected to backup no users (\"none\"), so all the modules backup have been switched to \"without user data\" mode. Please note that the \"exercise\" and \"workshop\" modules aren\'t compatible with this type of backup, so they have been deactivated completely.';
+$string['backupmissinguserinfoperms'] = 'Note: This backup contains no user data. Exercise and Workshop activities will not be included in the backup, since these modules are not compatible with this type of backup.';
+$string['backupnoneusersinfo'] = 'Note: This backup contains no users and so all activities have been switched to \"without user data\" mode. Exercise and Workshop activities will not be included in the backup, since these modules are not compatible with this type of backup.';
 $string['backupnonisowarning'] = 'Warning: this backup is from a non-Unicode version of Moodle (pre 1.6).  If this backup contains any non-ISO-8859-1 texts then they may be CORRUPTED if you try to restore them to this Unicode version of Moodle.  See the <a href=\"http://docs.moodle.org/en/Backup_FAQ\">Backup FAQ</a> for more information about how to recover this backup correctly.';
+$string['backupnext'] = 'Next backup';
 $string['backuporiginalname'] = 'Backup Name';
 $string['backuproleassignments'] = 'Backup role assignments for these roles';
 $string['backupsavetohelp'] = 'Full path to the directory where you want to save the backup files<br />(leave blank to save in its course default dir)';
@@ -272,12 +274,21 @@ $string['coursecategories'] = 'Course categories';
 $string['coursecategory'] = 'Course category';
 $string['coursecategorydeleted'] = 'Deleted course category $a';
 $string['coursecreators'] = 'Course creator';
-$string['coursecreatorsdescription'] = 'Course creators can create new courses and teach in them.';
+$string['coursecreatorsdescription'] = 'Course creators can create new courses.';
 $string['coursedeleted'] = 'Deleted course $a';
 $string['coursefiles'] = 'Course files';
 $string['courseformatdata'] = 'Course format data';
 $string['courseformats'] = 'Course formats';
 $string['coursegrades'] = 'Course grades';
+$string['coursehelpcategory'] = 'Position the course on the course listing and may make it easier for students to find it.';
+$string['coursehelpformat'] = 'The course main page will be displayed in this format.';
+$string['coursehelpnumberweeks'] = 'Number of weeks/topics displayed on the course main page.';
+$string['coursehelphiddensections'] = 'How the hidden sections in the course are displayed to students.';
+$string['coursehelpnewsitemsnumber'] = 'Number of recent items appearing on the course home page, in a news box down the right-hand side <br/>(0 means the news box won\'t appear)
+.';
+$string['coursehelpshowgrades'] = 'Enable the display of the gradebook. It does not prevent grades from being displayed within the individual activities.';
+$string['coursehelpmaximumupload'] = 'Define the largest size of file that can be uploaded in this course, limited by the site-wide setting.';
+$string['coursehelpmetacourse'] = 'Set the course a metacourse. A meta course takes enrolments (and other role assignments) from a \"child\" course or courses.';
 $string['coursehidden'] = 'This course is currently unavailable to students';
 $string['courseimportnotaught'] = 'You don\'t seem to be an editing teacher in any other courses, there are no courses for you to import from.';
 $string['courseinfo'] = 'Course info';
@@ -306,6 +317,7 @@ $string['courserequestsupport'] = 'Supporting information to help the administra
 $string['courserestore'] = 'Course restore';
 $string['courses'] = 'Courses';
 $string['coursescategory'] = 'Courses in the same category';
+$string['coursesettings'] = 'Course default settings';
 $string['coursesmovedout'] = 'Courses moved out from $a';
 $string['coursespending'] = 'Courses pending approval';
 $string['coursestaught'] = 'Courses I have taught';
@@ -643,9 +655,12 @@ $string['files'] = 'Files';
 $string['filesfolders'] = 'Files/folders';
 $string['filloutallfields'] = 'Please fill out all fields in this form';
 $string['findmorecourses'] = 'Find more courses...';
+$string['firstaccess'] = 'First access';
 $string['firstdayofweek'] = '0';
 $string['firstname'] = 'First name';
 $string['firsttime'] = 'Is this your first time here?';
+$string['flashlinkmessage'] = 'Please upgrade your Flash player now:';
+$string['flashupgrademessage'] = " The Flash plugin is required to play this content, but the version you have is too old.\n\n  You may need to log out and log in back after upgrade.";
 $string['folder'] = 'Folder';
 $string['folderclosed'] = 'Closed folder';
 $string['folderopened'] = 'Opened folder';
@@ -656,7 +671,9 @@ $string['forcedmode'] = 'forced mode';
 $string['forcelanguage'] = 'Force language';
 $string['forceno'] = 'Do not force';
 $string['forcepasswordchange'] = 'Force password change';
+$string['forcepasswordchangecheckfull'] = 'Are you absolutely sure you want to force a password change to $a ?';
 $string['forcepasswordchangehelp'] = 'Prompt user to change it on their next login';
+$string['forcepasswordchangenot'] = 'Could not force a password change to $a';
 $string['forcepasswordchangenotice'] = 'You must change your password to proceed.';
 $string['forcetheme'] = 'Force theme';
 $string['forgotaccount'] = 'Lost password?';
@@ -1109,6 +1126,7 @@ $string['noteachersyet'] = 'No teachers in this course yet';
 $string['notenrollable'] = 'This course is not enrollable at the moment.';
 $string['notenrolled'] = '$a is not enrolled in this course.';
 $string['notenrolledprofile'] = 'This profile is not available because this user is not enrolled in this course.';
+$string['noteusercannotrolldatesoncontext'] = '<strong>Note:</strong> The ability to roll dates when restoring this backup has been disabled because you lack the required permissions.';
 $string['noteuserschangednonetocourse'] = '<strong>Note:</strong> Course users need to be restored when restoring user data (in activities, files or messages). This setting has been changed for you.';
 $string['nothingnew'] = 'Nothing new since your last login';
 $string['nothingtodisplay'] = 'Nothing to display';
@@ -1211,6 +1229,7 @@ $string['potentialteachers'] = 'Potential teachers';
 $string['preferences'] = 'Preferences';
 $string['preferredlanguage'] = 'Preferred language';
 $string['preferredtheme'] = 'Preferred theme';
+$string['preprocessingbackupfile'] = 'Preprocessing backup file';
 $string['preview'] = 'Preview';
 $string['previewhtml'] = 'HTML Format Preview';
 $string['previeworchoose'] = 'Preview or choose a theme';
@@ -1225,6 +1244,8 @@ $string['publicdirectory1'] = 'Publish the site name only';
 $string['publicdirectory2'] = 'Publish the site name with a link';
 $string['publicdirectorytitle'] = 'See the current list of sites';
 $string['publicsitefileswarning'] = 'Note: files placed here can be accessed by anyone';
+$string['publicsitefileswarning2'] = 'Note: Files placed here can be accessed by anyone who knows (or can guess) the URL. For security reasons, it is recommended that any backup files are deleted immediately after restoring them.';
+$string['publicsitefileswarning3'] = 'Note: Files placed here can be accessed by anyone who knows (or can guess) the URL. <br />For security reasons, backup files should be saved in the secure backupdata folder only.';
 $string['question'] = 'Question';
 $string['questionsinthequestionbank'] = 'Questions in the question bank';
 $string['readinginfofrombackup'] = 'Reading info from backup';
@@ -1248,6 +1269,7 @@ for important notifications such as security alerts and new releases of Moodle.<
    picture of the Moodle community as a whole.</p>
 <p>If you choose, you can allow your site name, country and URL to be added to the public list of Moodle Sites.</p>
 <p>All new registrations are verified manually before they are added to the list, but once you are added you can update your registration (and your entry on the public list) at any time by resubmitting this form.</p>';
+$string['registrationinfotitle'] = 'Registration Information';
 $string['registrationno'] = 'No, I do not want to receive email';
 $string['registrationsend'] = 'Send registration information to moodle.org';
 $string['registrationyes'] = 'Yes, please notify me about important issues';
@@ -1283,10 +1305,22 @@ $string['resortcoursesbyname'] = 'Re-sort courses by name';
 $string['resource'] = 'Resource';
 $string['resources'] = 'Resources';
 $string['restore'] = 'Restore';
-$string['restorecancelled'] = 'Restore canceled';
+$string['restorecancelled'] = 'Restore cancelled';
+$string['restorecannotassignroles'] = 'Restore needs to assign roles and you do not have permission to do so';
+$string['restorecannotcreateorassignroles'] = 'Restore needs to create or assign roles and you do not have permission to do so';
+$string['restorecannotcreateuser'] = 'Restore needs to create user \'$a\' from backup file and you do not have permission to do so';
+$string['restorecannotoverrideperms'] = 'Restore needs to override permissions and you do not have permission to do so';
 $string['restorecoursenow'] = 'Restore this course now!';
+$string['restoredaccount'] = 'Restored account';
+$string['restoredaccountinfo'] = 'This account was imported from another server and the password has been lost. To set a new password by email, please click \"Continue\"';
 $string['restorefinished'] = 'Restore completed successfully';
 $string['restoreto'] = 'Restore to';
+$string['restoretositeadding'] = 'Warning: You are about to restore to the site front page, adding data to it!';
+$string['restoretositedeleting'] = 'Warning: You are about to restore to the site front page, deleting data from it first!';
+$string['restoreuserconflict'] = 'Trying to restore user \'$a\' from backup file will cause conflict';
+$string['restoreuserinfofailed'] = 'The restore process has stopped because you don\'t have permission to restore user data.';
+$string['restoreusersprecheck'] = 'Checking user data';
+$string['restoreusersprecheckerror'] = 'Some problems were detected when checking user data';
 $string['restricted'] = 'Restricted';
 $string['restrictmodules'] = 'Restrict activity modules?';
 $string['returningtosite'] = 'Returning to this web site?';
@@ -1378,6 +1412,7 @@ $string['showrecent'] = 'Show recent activity';
 $string['showreports'] = 'Show activity reports';
 $string['showsettings'] = 'Show settings';
 $string['showtheselogs'] = 'Show these logs';
+$string['showthishelpinlanguage'] = 'Show this help in language: $a';
 $string['since'] = 'Since';
 $string['sincelast'] = 'since last login';
 $string['site'] = 'Site';
@@ -1594,6 +1629,7 @@ $string['userprofilefor'] = 'User profile for $a';
 $string['users'] = 'Users';
 $string['usersnew'] = 'New users';
 $string['usersnoaccesssince'] = 'Inactive for more than';
+$string['userswithfiles'] = 'Users with files';
 $string['userzones'] = 'User zones';
 $string['usethiscourse'] = 'Use this course';
 $string['usingexistingcourse'] = 'Using existing course';
@@ -1632,8 +1668,7 @@ $string['weekshow'] = 'Show this week to $a';
 $string['welcometocourse'] = 'Welcome to $a';
 $string['welcometocoursetext'] = 'Welcome to $a->coursename!
 
-If you have not done so already, you should edit your profile page
-within the course so that we can learn more about you:
+If you have not done so already, you should edit your profile page so that we can learn more about you:
 
   $a->profileurl';
 $string['whattocallzip'] = 'What do you want to call the zip file?';
@@ -1681,4 +1716,6 @@ $string['zippingbackup'] = 'Zipping backup';
 
 $string['authenticationplugins'] = 'Authentication Plugins';
 $string['chooseauthmethod'] = 'Choose authentication plugin';
+$string['nocourses'] = 'No courses';
+$string['requestedcourses'] = 'Requested courses';
 ?>
