@@ -12,7 +12,7 @@
  *   Dropping an activity or resource on another activity or resource will
  *   always move the former just above the latter.
  *
- * $Id: section_classes.js,v 1.35.2.6 2008/10/08 12:13:39 nicolasconnault Exp $
+ * $Id: section_classes.js,v 1.35.2.12 2009/12/09 01:59:47 rwijaya Exp $
  */
 
 
@@ -79,7 +79,7 @@ section_class.prototype.init_section = function(id, group, config, isDraggable)
 
 
 section_class.prototype.init_buttons = function() {
-    var commandContainer = this.getEl().childNodes[2];
+    var commandContainer = YAHOO.util.Dom.getElementsByClassName('right',null,this.getEl())[0];
 
     //clear all but show only button
     var commandContainerCount = commandContainer.childNodes.length;
@@ -88,19 +88,21 @@ section_class.prototype.init_buttons = function() {
         commandContainer.removeChild(commandContainer.childNodes[i])
     }
 
-    if (!this.isWeekFormat) {
+    if (main.getString('courseformat', this.sectionId) != "weeks" && this.sectionId > 0) {
         var highlightbutton = main.mk_button('div', '/i/marker.gif', main.getString('marker', this.sectionId));
         YAHOO.util.Event.addListener(highlightbutton, 'click', this.mk_marker, this, true);
         commandContainer.appendChild(highlightbutton);
         this.highlightButton = highlightbutton;
     }
-    var viewbutton = main.mk_button('div', '/i/hide.gif', main.getString('hidesection', this.sectionId),
-            [['title', main.portal.strings['hide'] ]]);
+    
+    if (this.sectionId > 0 ) {        
+        var viewbutton = main.mk_button('div', '/i/hide.gif', main.getString('hidesection', this.sectionId), [['title', main.portal.strings['hide'] ]]);
     YAHOO.util.Event.addListener(viewbutton, 'click', this.toggle_hide, this,true);
     commandContainer.appendChild(viewbutton);
     this.viewButton = viewbutton;
 }
 
+}
 
 section_class.prototype.add_handle = function() {
     var handleRef = main.mk_button('a', '/i/move_2d.gif', main.getString('movesection', this.sectionId),
@@ -139,6 +141,12 @@ section_class.prototype.process_section = function() {
 
     // Find/edit resources
     this.resources_ul = this.content_td.getElementsByTagName('ul')[0];
+    var i=0;    
+    while (this.resources_ul && this.resources_ul.className != 'section img-text') {        
+        this.resources_ul = this.content_td.getElementsByTagName('ul')[i];
+        i++;
+    }
+    
     if (!this.resources_ul) {
         this.resources_ul = document.createElement('ul');
         this.resources_ul.className='section';
@@ -239,16 +247,16 @@ section_class.prototype.move_to_section = function(target) {
         } else if (main.sections[i] == target) {
             //encounter with target node
             if (this.debug) {
-				YAHOO.log("Found target "+main.sections[i].getEl().id);
-			}
-            main.sections[i].swap_dates(main.sections[eval(loopmodifier)]);
+                YAHOO.log("Found target "+main.sections[i].getEl().id);
+            }
             main.sections[i].swap_with_section(main.sections[eval(loopmodifier)]);
+            main.sections[i].swap_dates(main.sections[eval(loopmodifier)]);
             found = false;
             break;
         } else if (found) {
             //encounter with nodes inbetween
-            main.sections[i].swap_dates(main.sections[eval(loopmodifier)]);
             main.sections[i].swap_with_section(main.sections[eval(loopmodifier)]);
+            main.sections[i].swap_dates(main.sections[eval(loopmodifier)]);
         }
     }
 }
@@ -527,14 +535,20 @@ resource_class.prototype.init_resource = function(id, group, config, parentObj)
 
     this.hidden = false;
     if (YAHOO.util.Dom.hasClass(this.getEl().getElementsByTagName('a')[0], 'dimmed') ||
-        YAHOO.util.Dom.hasClass(this.getEl().getElementsByTagName('div')[0], 'dimmed_text')) {
+        YAHOO.util.Dom.hasClass(this.getEl().getElementsByTagName('span')[0], 'dimmed_text')) {
         this.hidden = true;
     }
     this.hiddenStored = null;
 
     this.groupmode = null;  // Can be null (i.e. does not apply), 0, 1 or 2.
 
-    this.linkContainer = this.getEl().getElementsByTagName('a')[0];
+    // Check for label first
+    firstspan = this.getEl().getElementsByTagName('span')[0];
+    if (firstspan.className == 'label' || firstspan.className == 'dimmed_text') {
+        this.linkContainer = firstspan;
+    } else {
+        this.linkContainer = this.getEl().getElementsByTagName('a')[0];
+    }
 
     this.commandContainer = null;
     this.indentLeftButton = null;
@@ -592,8 +606,8 @@ resource_class.prototype.init_buttons = function() {
     var moveRight = false;
     var updateButton = null;
 
-	// for RTL support
-	var isrtl = (document.getElementsByTagName("html")[0].dir=="rtl");
+    // for RTL support
+    var isrtl = (document.getElementsByTagName("html")[0].dir=="rtl");
 
     for (var x=0; x<buttons.length; x++) {
         if (buttons[x].className == 'editing_moveleft') {
@@ -711,10 +725,10 @@ resource_class.prototype.indent_left = function() {
 
 resource_class.prototype.indent_right = function() {
 
-	// for RTL support
-	var isrtl = (document.getElementsByTagName("html")[0].dir=="rtl");
+    // for RTL support
+    var isrtl = (document.getElementsByTagName("html")[0].dir=="rtl");
 
-	var spacer = YAHOO.util.Dom.getElementsByClassName('spacer',
+    var spacer = YAHOO.util.Dom.getElementsByClassName('spacer',
             'img', this.getEl())[0];
     if (!spacer) {
         var spacer = document.createElement('img');
@@ -757,6 +771,11 @@ resource_class.prototype.toggle_hide = function(target, e, superficial, force) {
     }
     if (this.hidden) {
         YAHOO.util.Dom.removeClass(this.linkContainer, 'dimmed');
+
+        if (YAHOO.util.Dom.hasClass(this.linkContainer, 'dimmed_text')) {
+            YAHOO.util.Dom.removeClass(this.linkContainer, 'dimmed_text');
+            YAHOO.util.Dom.addClass(this.linkContainer, 'label');
+        }
         this.viewButton.childNodes[0].src = this.viewButton.childNodes[0].src.replace(/show.gif/i, 'hide.gif');
         this.viewButton.childNodes[0].alt = this.viewButton.childNodes[0].alt.replace(strshow, strhide);
         this.viewButton.title = this.viewButton.title.replace(strshow, strhide);
@@ -767,6 +786,11 @@ resource_class.prototype.toggle_hide = function(target, e, superficial, force) {
         }
     } else {
         YAHOO.util.Dom.addClass(this.linkContainer, 'dimmed');
+
+        if (YAHOO.util.Dom.hasClass(this.linkContainer, 'label')) {
+            YAHOO.util.Dom.addClass(this.linkContainer, 'dimmed_text');
+            YAHOO.util.Dom.removeClass(this.linkContainer, 'label');
+        }
         this.viewButton.childNodes[0].src = this.viewButton.childNodes[0].src.replace(/hide.gif/i, 'show.gif');
         this.viewButton.childNodes[0].alt = this.viewButton.childNodes[0].alt.replace(strhide, strshow);
         this.viewButton.title = this.viewButton.title.replace(strhide, strshow);
@@ -818,7 +842,7 @@ resource_class.prototype.delete_button = function() {
         return false;
     }
     this.parentObj.remove_resource(this);
-    main.connect('DELETE', 'class=resource&id='+this.id);
+    main.connect('POST', 'class=resource&action=DELETE&id='+this.id);
 }
 
 
@@ -911,26 +935,12 @@ resource_class.prototype.endDrag = function() {
 }
 
 section_class.prototype.swap_dates = function(el){
-    var i=0;
-    while(this.getEl().getElementsByTagName("div")[i]) {
-        if (this.getEl().getElementsByTagName("div")[i].className == "weekdates") {
-            var tempdate = this.getEl().getElementsByTagName("div")[i].innerHTML;
-            var permi = i;
-        }
+    var i=1;
+    var divs = YAHOO.util.Selector.query('div .weekdates');
+
+    for (div in divs) {
+        divs[div].innerHTML = main.sectiondates[i];
         i++;
     }
-
-    var j=0;
-    while(el.getEl().getElementsByTagName("div")[j]) {
-        if (el.getEl().getElementsByTagName("div")[j].className == "weekdates") {
-            var permj = j;
-        }
-        j++;
-    }
-
-    if(tempdate) {
-        this.getEl().getElementsByTagName("div")[permi].innerHTML = el.getEl().getElementsByTagName("div")[permj].innerHTML;
-        el.getEl().getElementsByTagName("div")[permj].innerHTML = tempdate;
-    }
 }
 
