@@ -1,4 +1,4 @@
-<?php //$Id: filelib.php,v 1.50.2.25 2008/11/01 19:27:36 skodak Exp $
+<?php //$Id: filelib.php,v 1.50.2.33 2010/05/12 12:05:37 tjhunt Exp $
 
 define('BYTESERVING_BOUNDARY', 's1k2o3d4a5k6s7'); //unique string constant
 
@@ -38,7 +38,12 @@ function get_file_url($path, $options=null, $type='coursefile') {
 
     if ($CFG->slasharguments) {
         $parts = explode('/', $path);
-        $parts = array_map('rawurlencode', $parts);
+        foreach ($parts as $key => $part) {
+        /// anchor dash character should not be encoded
+            $subparts = explode('#', $part);
+            $subparts = array_map('rawurlencode', $subparts);
+            $parts[$key] = implode('#', $subparts);
+        }
         $path  = implode('/', $parts);
         $ffurl = $url.'/'.$path;
         $separator = '?';
@@ -379,6 +384,8 @@ function get_mimetypes_array() {
         'm3u'  => array ('type'=>'audio/x-mpegurl', 'icon'=>'audio.gif'),
         'mp3'  => array ('type'=>'audio/mp3', 'icon'=>'audio.gif'),
         'mp4'  => array ('type'=>'video/mp4', 'icon'=>'video.gif'),
+        'm4v'  => array ('type'=>'video/mp4', 'icon'=>'video.gif'),
+        'm4a'  => array ('type'=>'audio/mp4', 'icon'=>'audio.gif'),
         'mpeg' => array ('type'=>'video/mpeg', 'icon'=>'video.gif'),
         'mpe'  => array ('type'=>'video/mpeg', 'icon'=>'video.gif'),
         'mpg'  => array ('type'=>'video/mpeg', 'icon'=>'video.gif'),
@@ -417,10 +424,10 @@ function get_mimetypes_array() {
 
         'ps'   => array ('type'=>'application/postscript', 'icon'=>'pdf.gif'),
         'qt'   => array ('type'=>'video/quicktime', 'icon'=>'video.gif'),
-        'ra'   => array ('type'=>'audio/x-realaudio', 'icon'=>'audio.gif'),
-        'ram'  => array ('type'=>'audio/x-pn-realaudio', 'icon'=>'audio.gif'),
+        'ra'   => array ('type'=>'audio/x-realaudio-plugin', 'icon'=>'audio.gif'),
+        'ram'  => array ('type'=>'audio/x-pn-realaudio-plugin', 'icon'=>'audio.gif'),
         'rhb'  => array ('type'=>'text/xml', 'icon'=>'xml.gif'),
-        'rm'   => array ('type'=>'audio/x-pn-realaudio', 'icon'=>'audio.gif'),
+        'rm'   => array ('type'=>'audio/x-pn-realaudio-plugin', 'icon'=>'audio.gif'),
         'rtf'  => array ('type'=>'text/rtf', 'icon'=>'text.gif'),
         'rtx'  => array ('type'=>'text/richtext', 'icon'=>'text.gif'),
         'sh'   => array ('type'=>'application/x-sh', 'icon'=>'text.gif'),
@@ -489,7 +496,7 @@ function mimeinfo($element, $filename) {
         $mimeinfo = get_mimetypes_array();
     }
 
-    if (eregi('\.([a-z0-9]+)$', $filename, $match)) {
+    if (preg_match('/\.([a-zA-Z0-9]+)$/', $filename, $match)) {
         if (isset($mimeinfo[strtolower($match[1])][$element])) {
             return $mimeinfo[strtolower($match[1])][$element];
         } else {
@@ -645,7 +652,7 @@ function send_temp_file_finished($path) {
  * @param string $mimetype Include to specify the MIME type; leave blank to have it guess the type from $filename
  */
 function send_file($path, $filename, $lifetime = 'default' , $filter=0, $pathisstring=false, $forcedownload=false, $mimetype='') {
-    global $CFG, $COURSE;
+    global $CFG, $COURSE, $SESSION;
 
     // MDL-11789, apply $CFG->filelifetime here
     if ($lifetime === 'default') {
@@ -662,6 +669,21 @@ function send_file($path, $filename, $lifetime = 'default' , $filter=0, $pathiss
     $isFF         = check_browser_version('Firefox', '1.5'); // only FF > 1.5 properly tested
     $mimetype     = ($forcedownload and !$isFF) ? 'application/x-forcedownload' :
                          ($mimetype ? $mimetype : mimeinfo('type', $filename));
+
+    // If the file is a Flash file and that the user flash player is outdated return a flash upgrader MDL-20841
+    if (!empty($CFG->excludeoldflashclients) && $mimetype == 'application/x-shockwave-flash'&& !empty($SESSION->flashversion)) {
+        $userplayerversion = explode('.', $SESSION->flashversion);
+        $requiredplayerversion = explode('.', $CFG->excludeoldflashclients);
+        if (($userplayerversion[0] <  $requiredplayerversion[0]) ||
+            ($userplayerversion[0] == $requiredplayerversion[0] && $userplayerversion[1] < $requiredplayerversion[1]) ||
+            ($userplayerversion[0] == $requiredplayerversion[0] && $userplayerversion[1] == $requiredplayerversion[1] 
+             && $userplayerversion[2] < $requiredplayerversion[2])) {
+            $path = $CFG->dirroot."/lib/flashdetect/flashupgrade.swf";  // Alternate content asking user to upgrade Flash
+            $filename = "flashupgrade.swf";
+            $lifetime = 0;  // Do not cache
+        }
+    }
+
     $lastmodified = $pathisstring ? time() : filemtime($path);
     $filesize     = $pathisstring ? strlen($path) : filesize($path);
 
@@ -941,7 +963,7 @@ function put_records_csv($file, $records, $table = NULL) {
  * @param $location the path to remove.
  */
 function fulldelete($location) {
-    if (is_dir($location)) {
+    if (is_dir($location) and !is_link($location)) {
         $currdir = opendir($location);
         while (false !== ($file = readdir($currdir))) {
             if ($file <> ".." && $file <> ".") {
