@@ -1,4 +1,4 @@
-<?php // $Id: grade_category.php,v 1.96.2.22 2009/01/08 16:01:43 nicolasconnault Exp $
+<?php // $Id: grade_category.php,v 1.96.2.31 2010/02/03 02:22:58 andyjdavis Exp $
 
 ///////////////////////////////////////////////////////////////////////////
 //                                                                       //
@@ -143,6 +143,11 @@ class grade_category extends grade_object {
      */
     var $forceable = array('aggregation', 'keephigh', 'droplow', 'aggregateonlygraded', 'aggregateoutcomes', 'aggregatesubcats');
 
+    /**
+     * String representing the aggregation coefficient. Variable is used as cache.
+     */
+    var $coefstring = null;
+
     /**
      * Builds this category's path string based on its parents (if any) and its own id number.
      * This is typically done just before inserting this object in the DB for the first time,
@@ -422,6 +427,9 @@ class grade_category extends grade_object {
             $items = get_records_sql($sql);
         }
 
+        // needed mostly for SUM agg type
+        $this->auto_update_max($items);
+
         if ($userid) {
             $usersql = "AND g.userid=$userid";
         } else {
@@ -545,7 +553,7 @@ class grade_category extends grade_object {
         }
 
         // limit and sort
-        $this->apply_limit_rules($grade_values);
+        $this->apply_limit_rules($grade_values, $items);
         asort($grade_values, SORT_NUMERIC);
 
         // let's see we have still enough grades to do any statistics
@@ -564,11 +572,7 @@ class grade_category extends grade_object {
         // recalculate the grade back to requested range
         $finalgrade = grade_grade::standardise_score($agg_grade, 0, 1, $this->grade_item->grademin, $this->grade_item->grademax);
 
-        if (is_null($finalgrade)) {
-            $grade->finalgrade = null;
-        } else {
-            $grade->finalgrade = (float)bounded_number($this->grade_item->grademin, $finalgrade, $this->grade_item->grademax);
-        }
+        $grade->finalgrade = $this->grade_item->bounded_grade($finalgrade);
 
         // update in db if changed
         if (grade_floats_different($grade->finalgrade, $oldfinalgrade)) {
@@ -638,19 +642,23 @@ class grade_category extends grade_object {
                 }
                 break;
 
-            case GRADE_AGGREGATE_WEIGHTED_MEAN2: // Weighted average of all existing final grades, weight is the range of grade (ususally grademax)
+            case GRADE_AGGREGATE_WEIGHTED_MEAN2:
+                // Weighted average of all existing final grades with optional extra credit flag,
+                // weight is the range of grade (ususally grademax)
                 $weightsum = 0;
-                $sum       = 0;
+                $sum       = null;
                 foreach($grade_values as $itemid=>$grade_value) {
                     $weight = $items[$itemid]->grademax - $items[$itemid]->grademin;
                     if ($weight <= 0) {
                         continue;
                     }
-                    $weightsum += $weight;
-                    $sum       += $weight * $grade_value;
+                    if ($items[$itemid]->aggregationcoef == 0) {
+                        $weightsum += $weight;
+                    }
+                    $sum += $weight * $grade_value;
                 }
                 if ($weightsum == 0) {
-                    $agg_grade = null;
+                    $agg_grade = $sum; // only extra credits
                 } else {
                     $agg_grade = $sum / $weightsum;
                 }
@@ -658,7 +666,7 @@ class grade_category extends grade_object {
 
             case GRADE_AGGREGATE_EXTRACREDIT_MEAN: // special average
                 $num = 0;
-                $sum = 0;
+                $sum = null;
                 foreach($grade_values as $itemid=>$grade_value) {
                     if ($items[$itemid]->aggregationcoef == 0) {
                         $num += 1;
@@ -685,6 +693,53 @@ class grade_category extends grade_object {
         return $agg_grade;
     }
 
+    /**
+     * Some aggregation tpyes may update max grade
+     * @param array $items sub items
+     * @return void
+     */
+    function auto_update_max($items) {
+        if ($this->aggregation != GRADE_AGGREGATE_SUM) {
+            // not needed at all
+            return;
+        }
+
+        if (!$items) {
+            if ($this->grade_item->grademax != 0 or $this->grade_item->gradetype != GRADE_TYPE_VALUE) {
+                $this->grade_item->grademax  = 0;
+                $this->grade_item->grademin  = 0;
+                $this->grade_item->gradetype = GRADE_TYPE_VALUE;
+                $this->grade_item->update('aggregation');
+            }
+            return;
+        }
+
+        //find max grade possible
+        $maxes = array();
+        foreach ($items as $item) {
+            if ($item->aggregationcoef > 0) {
+                // extra credit from this activity - does not affect total
+                continue;
+            }
+            if ($item->gradetype == GRADE_TYPE_VALUE) {
+                $maxes[$item->id] = $item->grademax;
+            } else if ($item->gradetype == GRADE_TYPE_SCALE) {
+                $maxes[$item->id] = $item->grademax; // 0 = nograde, 1 = first scale item, 2 = second scale item
+            }
+        }
+        // apply droplow and keephigh
+        $this->apply_limit_rules($maxes, $items);
+        $max = array_sum($maxes);
+
+        // update db if anything changed
+        if ($this->grade_item->grademax != $max or $this->grade_item->grademin != 0 or $this->grade_item->gradetype != GRADE_TYPE_VALUE) {
+            $this->grade_item->grademax  = $max;
+            $this->grade_item->grademin  = 0;
+            $this->grade_item->gradetype = GRADE_TYPE_VALUE;
+            $this->grade_item->update('aggregation');
+        }
+    }
+
     /**
      * internal function for category grades summing
      *
@@ -719,32 +774,10 @@ class grade_category extends grade_object {
             }
         }
 
-        $max = 0;
-
-        //find max grade
-        foreach ($items as $item) {
-            if ($item->aggregationcoef > 0) {
-                // extra credit from this activity - does not affect total
-                continue;
-            }
-            if ($item->gradetype == GRADE_TYPE_VALUE) {
-                $max += $item->grademax;
-            } else if ($item->gradetype == GRADE_TYPE_SCALE) {
-                $max += $item->grademax - 1; // scales min is 1
-            }
-        }
-
-        if ($this->grade_item->grademax != $max or $this->grade_item->grademin != 0 or $this->grade_item->gradetype != GRADE_TYPE_VALUE){
-            $this->grade_item->grademax = $max;
-            $this->grade_item->grademin = 0;
-            $this->grade_item->gradetype = GRADE_TYPE_VALUE;
-            $this->grade_item->update('aggregation');
-        }
-
-        $this->apply_limit_rules($grade_values);
+        $this->apply_limit_rules($grade_values, $items);
 
         $sum = array_sum($grade_values);
-        $grade->finalgrade = bounded_number($this->grade_item->grademin, $sum, $this->grade_item->grademax);
+        $grade->finalgrade = $this->grade_item->bounded_grade($sum);
 
         // update in db if changed
         if (grade_floats_different($grade->finalgrade, $oldfinalgrade)) {
@@ -757,22 +790,54 @@ class grade_category extends grade_object {
     /**
      * Given an array of grade values (numerical indices), applies droplow or keephigh
      * rules to limit the final array.
-     * @param array $grade_values
+     * @param array $grade_values itemid=>$grade_value float
+     * @param array $items grade titem objects
      * @return array Limited grades.
      */
-    function apply_limit_rules(&$grade_values) {
-        arsort($grade_values, SORT_NUMERIC);
+    function apply_limit_rules(&$grade_values, $items) {
+        $extraused = $this->is_extracredit_used();
+
         if (!empty($this->droplow)) {
-            for ($i = 0; $i < $this->droplow; $i++) {
-                array_pop($grade_values);
+            asort($grade_values, SORT_NUMERIC);
+            $dropped = 0;
+            foreach ($grade_values as $itemid=>$value) {
+                if ($dropped < $this->droplow) {
+                    if ($extraused and $items[$itemid]->aggregationcoef > 0) {
+                        // no drop low for extra credits
+                    } else {
+                        unset($grade_values[$itemid]);
+                        $dropped++;
+                    }
+                } else {
+                    // we have dropped enough
+                    break;
+                }
             }
-        } elseif (!empty($this->keephigh)) {
-            while (count($grade_values) > $this->keephigh) {
-                array_pop($grade_values);
+
+        } else if (!empty($this->keephigh)) {
+            arsort($grade_values, SORT_NUMERIC);
+            $kept = 0;
+            foreach ($grade_values as $itemid=>$value) {
+                if ($extraused and $items[$itemid]->aggregationcoef > 0) {
+                    // we keep all extra credits
+                } else if ($kept < $this->keephigh) {
+                    $kept++;
+                } else {
+                    unset($grade_values[$itemid]);
+                }
             }
         }
     }
 
+    /**
+     * Returns true if category uses extra credit of any kind
+     * @return boolean true if extra credit used
+     */
+    function is_extracredit_used() {
+        return ($this->aggregation == GRADE_AGGREGATE_WEIGHTED_MEAN2
+             or $this->aggregation == GRADE_AGGREGATE_EXTRACREDIT_MEAN
+             or $this->aggregation == GRADE_AGGREGATE_SUM);
+    }
 
     /**
      * Returns true if category uses special aggregation coeficient
@@ -780,11 +845,60 @@ class grade_category extends grade_object {
      */
     function is_aggregationcoef_used() {
         return ($this->aggregation == GRADE_AGGREGATE_WEIGHTED_MEAN
+             or $this->aggregation == GRADE_AGGREGATE_WEIGHTED_MEAN2
              or $this->aggregation == GRADE_AGGREGATE_EXTRACREDIT_MEAN
              or $this->aggregation == GRADE_AGGREGATE_SUM);
 
     }
 
+    /**
+     * Recursive function to find which weight/extra credit field to use in the grade item form. Inherits from a parent category
+     * if that category has aggregatesubcats set to true.
+     * @param string $coefstring
+     * @return string $coefstring
+     */
+    function get_coefstring($first=true) {
+        if (!is_null($this->coefstring)) {
+            return $this->coefstring;
+        }
+
+        $overriding_coefstring = null;
+
+        // Stop recursing upwards if this category aggregates subcats or has no parent
+        if (!$first && !$this->aggregatesubcats) {
+            if ($parent_category = $this->load_parent_category()) {
+                return $parent_category->get_coefstring(false);
+            } else {
+                return null;
+            }
+        } elseif ($first) {
+            if (!$this->aggregatesubcats) {
+                if ($parent_category = $this->load_parent_category()) {
+                    $overriding_coefstring = $parent_category->get_coefstring(false);
+                }
+            }
+        }
+
+        // If an overriding coefstring has trickled down from one of the parent categories, return it. Otherwise, return self.
+        if (!is_null($overriding_coefstring)) {
+            return $overriding_coefstring;
+        }
+
+        // No parent category is overriding this category's aggregation, return its string
+        if ($this->aggregation == GRADE_AGGREGATE_WEIGHTED_MEAN) {
+            $this->coefstring = 'aggregationcoefweight';
+        } else if ($this->aggregation == GRADE_AGGREGATE_WEIGHTED_MEAN2) {
+            $this->coefstring = 'aggregationcoefextrasum';
+        } else if ($this->aggregation == GRADE_AGGREGATE_EXTRACREDIT_MEAN) {
+            $this->coefstring = 'aggregationcoefextra';
+        } else if ($this->aggregation == GRADE_AGGREGATE_SUM) {
+            $this->coefstring = 'aggregationcoefextrasum';
+        } else {
+            $this->coefstring = 'aggregationcoef';
+        }
+        return $this->coefstring;
+    }
+
     /**
      * Returns tree with all grade_items and categories as elements
      * @static
@@ -1260,6 +1374,18 @@ class grade_category extends grade_object {
                 }
             }
         }
+
+        //if marking category visible make sure parent category is visible MDL-21367
+        if( !$hidden ) {
+            $category_array = grade_category::fetch_all(array('id'=>$this->parent));
+            if ($category_array && array_key_exists($this->parent, $category_array)) {
+                $category = $category_array[$this->parent];
+                //call set_hidden on the category regardless of whether it is hidden as its parent might be hidden
+                //if($category->is_hidden()) {
+                    $category->set_hidden($hidden, false);
+                //}
+            }
+        }
     }
 
     /**
