@@ -1,4 +1,4 @@
-<?php // $Id: grade_item.php,v 1.130.2.28 2008/10/24 17:47:56 skodak Exp $
+<?php // $Id: grade_item.php,v 1.130.2.37 2010/04/15 16:37:07 tjhunt Exp $
 
 ///////////////////////////////////////////////////////////////////////////
 //                                                                       //
@@ -591,7 +591,7 @@ class grade_item extends grade_object {
     function set_hidden($hidden, $cascade=false) {
         $this->hidden = $hidden;
         $this->update();
-
+        
         if ($cascade) {
             if ($grades = grade_grade::fetch_all(array('itemid'=>$this->id))) {
                 foreach($grades as $grade) {
@@ -600,6 +600,18 @@ class grade_item extends grade_object {
                 }
             }
         }
+
+        //if marking item visible make sure category is visible MDL-21367
+        if( !$hidden ) {
+            $category_array = grade_category::fetch_all(array('id'=>$this->categoryid));
+            if ($category_array && array_key_exists($this->categoryid, $category_array)) {
+                $category = $category_array[$this->categoryid];
+                //call set_hidden on the category regardless of whether it is hidden as its parent might be hidden
+                //if($category->is_hidden()) {
+                    $category->set_hidden($hidden, false);
+                //}
+            }
+        }
     }
 
     /**
@@ -735,7 +747,7 @@ class grade_item extends grade_object {
             $rawgrade *= $this->multfactor;
             $rawgrade += $this->plusfactor;
 
-            return bounded_number($this->grademin, $rawgrade, $this->grademax);
+            return $this->bounded_grade($rawgrade);
 
         } else if ($this->gradetype == GRADE_TYPE_SCALE) { // Dealing with a scale value
             if (empty($this->scale)) {
@@ -756,7 +768,7 @@ class grade_item extends grade_object {
                 $rawgrade = grade_grade::standardise_score($rawgrade, $rawmin, $rawmax, $this->grademin, $this->grademax);
             }
 
-            return (int)bounded_number(0, round($rawgrade+0.00001), $this->grademax);
+            return $this->bounded_grade($rawgrade);
 
 
         } else if ($this->gradetype == GRADE_TYPE_TEXT or $this->gradetype == GRADE_TYPE_NONE) { // no value
@@ -871,7 +883,7 @@ class grade_item extends grade_object {
      * @return object Grade_category
      */
     function load_item_category() {
-        if (empty($this->category->id)) {
+        if (empty($this->item_category->id)) {
             $this->item_category = $this->get_item_category();
         }
         return $this->item_category;
@@ -1163,9 +1175,10 @@ class grade_item extends grade_object {
     /**
      * Returns the most descriptive field for this object. This is a standard method used
      * when we do not know the exact type of an object.
+     * @param boolean $fulltotal: if the item is a category total, returns $categoryname."total" instead of "Category total" or "Course total"
      * @return string name
      */
-    function get_name() {
+    function get_name($fulltotal=false) {
         if (!empty($this->itemname)) {
             // MDL-10557
             return format_string($this->itemname);
@@ -1174,7 +1187,14 @@ class grade_item extends grade_object {
             return get_string('coursetotal', 'grades');
 
         } else if ($this->is_category_item()) {
-            return get_string('categorytotal', 'grades');
+            if ($fulltotal) {
+                $category = $this->load_parent_category();
+                $a = new stdClass();
+                $a->category = $category->get_name();
+                return get_string('categorytotalfull', 'grades', $a);
+            } else {
+                return get_string('categorytotal', 'grades');
+            }
 
         } else {
             return get_string('grade');
@@ -1200,6 +1220,13 @@ class grade_item extends grade_object {
             return false;
         }
 
+        // MDL-19407 If moving from a non-SWM category to a SWM category, convert aggregationcoef to 0
+        $currentparent = $this->load_parent_category();
+
+        if ($currentparent->aggregation != GRADE_AGGREGATE_WEIGHTED_MEAN2 && $parent_category->aggregation == GRADE_AGGREGATE_WEIGHTED_MEAN2) {
+            $this->aggregationcoef = 0;
+        }
+
         $this->force_regrading();
 
         // set new parent
@@ -1209,6 +1236,43 @@ class grade_item extends grade_object {
         return $this->update();
     }
 
+    /**
+     * Makes sure value is a valid grade value.
+     * @param float $gradevalue
+     * @return mixed float or int fixed grade value
+     */
+    function bounded_grade($gradevalue) {
+        global $CFG;
+
+        if (is_null($gradevalue)) {
+            return null;
+        }
+
+        if ($this->gradetype == GRADE_TYPE_SCALE) {
+            // no >100% grades hack for scale grades!
+            // 1.5 is rounded to 2 ;-)
+            return (int)bounded_number($this->grademin, round($gradevalue+0.00001), $this->grademax);
+        }
+
+        $grademax = $this->grademax;
+
+        // NOTE: if you change this value you must manually reset the needsupdate flag in all grade items
+        $maxcoef = isset($CFG->gradeoverhundredprocentmax) ? $CFG->gradeoverhundredprocentmax : 10; // 1000% max by default
+
+        if (!empty($CFG->unlimitedgrades)) {
+            // NOTE: if you change this value you must manually reset the needsupdate flag in all grade items
+            $grademax = $grademax * $maxcoef;
+        } else if ($this->is_category_item() or $this->is_course_item()) {
+            $category = $this->load_item_category();
+            if ($category->aggregation >= 100) {
+                // grade >100% hack
+                $grademax = $grademax * $maxcoef;
+            }
+        }
+
+        return (float)bounded_number($this->grademin, $gradevalue, $grademax);
+    }
+
     /**
      * Finds out on which other items does this depend directly when doing calculation or category agregation
      * @param bool $reset_cache
@@ -1384,15 +1448,9 @@ class grade_item extends grade_object {
         if ($finalgrade !== false) {
             if ($this->is_overridable_item()) {
                 $grade->overridden = time();
-            } else {
-                $grade->overridden = 0;
             }
 
-            if (is_null($finalgrade)) {
-                $grade->finalgrade = null;
-            } else {
-                $grade->finalgrade = bounded_number($this->grademin, $finalgrade, $this->grademax);
-            }
+            $grade->finalgrade = $this->bounded_grade($finalgrade);
         }
 
         // do we have comment from teacher?
@@ -1414,7 +1472,7 @@ class grade_item extends grade_object {
         } else if (grade_floats_different($grade->finalgrade, $oldgrade->finalgrade)
                 or $grade->feedback       !== $oldgrade->feedback
                 or $grade->feedbackformat != $oldgrade->feedbackformat
-                or $grade->overridden     != $oldgrade->overridden) {
+                or ($oldgrade->overridden == 0 and $grade->overridden > 0)) {
             $grade->timemodified = time(); // hack alert - date graded
             $result = $grade->update($source);
         } else {
@@ -1735,15 +1793,12 @@ class grade_item extends grade_object {
 
         } else {
             // normalize
-            $result = bounded_number($this->grademin, $result, $this->grademax);
-            if ($this->gradetype == GRADE_TYPE_SCALE) {
-                $result = round($result+0.00001); // round scales upwards
-            }
-            $grade->finalgrade = $result;
+            $grade->finalgrade = $this->bounded_grade($result);
         }
 
         // update in db if changed
         if (grade_floats_different($grade->finalgrade, $oldfinalgrade)) {
+            $grade->timemodified = time();
             $grade->update('compute');
         }
 
@@ -1878,7 +1933,7 @@ class grade_item extends grade_object {
         global $USER;
 
         // Determine which display type to use for this average
-        if ($USER->gradeediting[$this->courseid]) {
+        if (isset($USER->gradeediting) && $USER->gradeediting[$this->courseid]) {
             $displaytype = GRADE_DISPLAY_TYPE_REAL;
 
         } else if ($rangesdisplaytype == GRADE_REPORT_PREFERENCE_INHERIT) { // no ==0 here, please resave report and user prefs
@@ -1908,5 +1963,21 @@ class grade_item extends grade_object {
         return $grademin.'&ndash;'. $grademax;
     }
 
+    /**
+     * Queries parent categories recursively to find the aggregationcoef type that applies to this
+     * grade item.
+     */
+    function get_coefstring() {
+        $parent_category = $this->load_parent_category();
+        if ($this->is_category_item()) {
+            $parent_category = $parent_category->load_parent_category();
+        }
+
+        if ($parent_category->is_aggregationcoef_used()) {
+            return $parent_category->get_coefstring();
+        } else {
+            return false;
+        }
+    }
 }
 ?>
