@@ -1,4 +1,4 @@
-<?php  //$Id: grouplib.php,v 1.22.2.7 2008/04/13 21:58:31 skodak Exp $
+<?php  //$Id: grouplib.php,v 1.22.2.10 2009/11/30 17:18:44 sam_marshall Exp $
 
 /**
  * Groups not used in course or activity
@@ -346,7 +346,7 @@ function groups_print_course_menu($course, $urlroot, $return=false) {
 
     $context = get_context_instance(CONTEXT_COURSE, $course->id);
     if ($groupmode == VISIBLEGROUPS or has_capability('moodle/site:accessallgroups', $context)) {
-        $allowedgroups = groups_get_all_groups($course->id, 0);
+        $allowedgroups = groups_get_all_groups($course->id, 0, $course->defaultgroupingid);
         // detect changes related to groups and fix active group
         if (!empty($SESSION->activegroup[$course->id][VISIBLEGROUPS][0])) {
             if (!array_key_exists($SESSION->activegroup[$course->id][VISIBLEGROUPS][0], $allowedgroups)) {
@@ -362,7 +362,7 @@ function groups_print_course_menu($course, $urlroot, $return=false) {
         }
 
     } else {
-        $allowedgroups = groups_get_all_groups($course->id, $USER->id);
+        $allowedgroups = groups_get_all_groups($course->id, $USER->id, $course->defaultgroupingid);
         // detect changes related to groups and fix active group
         if (isset($SESSION->activegroup[$course->id][SEPARATEGROUPS][0])) {
             if ($SESSION->activegroup[$course->id][SEPARATEGROUPS][0] == 0) {
@@ -418,7 +418,7 @@ function groups_print_course_menu($course, $urlroot, $return=false) {
  * Print group menu selector for activity.
  * @param object $cm course module object
  * @param string $urlroot return address that users get to if they choose an option;
- *   should include any parameters needed, e.g. 'view.php?id=34'
+ *   should include any parameters needed, e.g. "$CFG->wwwroot/mod/forum/view.php?id=34"
  * @param boolean $return return as string instead of printing
  * @param boolean $hideallparticipants If true, this prevents the 'All participants'
  *   option from appearing in cases where it normally would. This is intended for
@@ -431,6 +431,14 @@ function groups_print_course_menu($course, $urlroot, $return=false) {
 function groups_print_activity_menu($cm, $urlroot, $return=false, $hideallparticipants=false) {
     global $CFG, $USER, $SESSION;
 
+    // Display error if urlroot is not absolute (this causes the non-JS version
+    // to break)
+    if (strpos($urlroot, 'http') !== 0) { // Will also work for https
+        debugging('groups_print_activity_menu requires absolute URL for ' .
+            '$urlroot, not <tt>' . s($urlroot) . '</tt>. Example: ' .
+            'groups_print_activity_menu($cm, $CFG->wwwroot . \'/mod/mymodule/view.php?id=13\');',
+            DEBUG_DEVELOPER);
+    }
     // groupings are ignored when not enabled
     if (empty($CFG->enablegroupings)) {
         $cm->groupingid = 0;
@@ -548,7 +556,7 @@ function groups_get_course_group($course, $update=false) {
         if ($groupmode == 'aag') {
             $SESSION->activegroup[$course->id][$groupmode][0] = 0; // all groups by default if user has accessallgroups
 
-        } else if ($usergroups = groups_get_all_groups($course->id, $USER->id, 0)) {
+        } else if ($usergroups = groups_get_all_groups($course->id, $USER->id, $course->defaultgroupingid)) {
             $fistgroup = reset($usergroups);
             $SESSION->activegroup[$course->id][$groupmode][0] = $fistgroup->id;
 
@@ -572,9 +580,9 @@ function groups_get_course_group($course, $update=false) {
         } else {
             // first make list of allowed groups
             if ($groupmode == VISIBLEGROUPS or $groupmode == 'aag') {
-                $allowedgroups = groups_get_all_groups($course->id, 0, 0);
+                $allowedgroups = groups_get_all_groups($course->id, 0, $course->defaultgroupingid);
             } else {
-                $allowedgroups = groups_get_all_groups($course->id, $USER->id, 0);
+                $allowedgroups = groups_get_all_groups($course->id, $USER->id, $course->defaultgroupingid);
             }
 
             if ($allowedgroups and array_key_exists($changegroup, $allowedgroups)) {
