@@ -1,4 +1,4 @@
-<?php  // $Id: questionlib.php,v 1.119.2.23 2008/12/12 09:00:03 tjhunt Exp $
+<?php  // $Id: questionlib.php,v 1.119.2.30 2010/04/07 09:47:17 tjhunt Exp $
 /**
  * Code for handling and processing questions
  *
@@ -822,7 +822,9 @@ function get_question_states(&$questions, $cmoptions, $attempt, $lastattemptid =
 
     // The question field must be listed first so that it is used as the
     // array index in the array returned by get_records_sql
-    $statefields = 'n.questionid as question, s.*, n.sumpenalty, n.manualcomment';
+    $statefields = 'n.questionid as question, s.id, s.attempt, s.originalquestion, ' .
+            's.seq_number, s.answer, s.timestamp, s.event, s.grade, s.raw_grade, ' .
+            's.penalty, n.sumpenalty, n.manualcomment';
     // Load the newest states for the questions
     $sql = "SELECT $statefields".
            "  FROM {$CFG->prefix}question_states s,".
@@ -856,12 +858,15 @@ function get_question_states(&$questions, $cmoptions, $attempt, $lastattemptid =
                 // If the new attempt is to be based on this previous attempt.
                 // Find the responses from the previous attempt and save them to the new session
 
-                // Load the last graded state for the question
-                $statefields = 'n.questionid as question, s.*, n.sumpenalty';
+                // Load the last graded state for the question. Note, $statefields is
+                // the same as above, except that we don't want n.manualcomment.
+                $statefields = 'n.questionid as question, s.id, s.attempt, s.originalquestion, ' .
+                        's.seq_number, s.answer, s.timestamp, s.event, s.grade, s.raw_grade, ' .
+                        's.penalty, n.sumpenalty';
                 $sql = "SELECT $statefields".
                        "  FROM {$CFG->prefix}question_states s,".
                        "       {$CFG->prefix}question_sessions n".
-                       " WHERE s.id = n.newgraded".
+                       " WHERE s.id = n.newest".
                        "   AND n.attemptid = '$lastattemptid'".
                        "   AND n.questionid = '$i'";
                 if (!$laststate = get_record_sql($sql)) {
@@ -1693,6 +1698,19 @@ function get_html_head_contributions(&$questionlist, &$questions, &$states) {
     return implode("\n", array_unique($contributions));
 }
 
+/**
+ * Like @see{get_html_head_contributions} but for the editing page
+ * question/question.php.
+ *
+ * @param $question A question object. Only $question->qtype is used.
+ * @return string some HTML code that can go inside the head tag.
+ */
+function get_editing_head_contributions($question) {
+    global $QTYPES;
+    $contributions = $QTYPES[$question->qtype]->get_editing_head_contributions();
+    return implode("\n", array_unique($contributions));
+}
+
 /**
  * Prints a question
  *
@@ -1886,7 +1904,14 @@ function question_category_select_menu($contexts, $top = false, $currentcat = 0,
 * @return object The default category - the category in the course context
 */
 function question_make_default_categories($contexts) {
+    static $preferredlevels = array(
+        CONTEXT_COURSE => 4,
+        CONTEXT_MODULE => 3,
+        CONTEXT_COURSECAT => 2,
+        CONTEXT_SYSTEM => 1,
+    );
     $toreturn = null;
+    $preferredness = 0;
     // If it already exists, just return it.
     foreach ($contexts as $key => $context) {
         if (!$categoryrs = get_recordset_select("question_categories", "contextid = '{$context->id}'", 'sortorder, name', '*', '', 1)) {
@@ -1907,12 +1932,16 @@ function question_make_default_categories($contexts) {
                 }
             }
         }
-        if ($context->contextlevel == CONTEXT_COURSE){
-            $toreturn = clone($category);
+        if ($preferredlevels[$context->contextlevel] > $preferredness &&
+                has_any_capability(array('moodle/question:usemine', 'moodle/question:useall'), $context)) {
+            $toreturn = $category;
+            $preferredness = $preferredlevels[$context->contextlevel];
         }
     }
 
-
+    if (!is_null($toreturn)) {
+        $toreturn = clone($toreturn);
+    }
     return $toreturn;
 }
 
@@ -2056,7 +2085,10 @@ function get_import_export_formats( $type ) {
         if ($provided) {
             $formatname = get_string($fileformat, 'quiz');
             if ($formatname == "[[$fileformat]]") {
-                $formatname = $fileformat;  // Just use the raw folder name
+                $formatname = get_string($fileformat, 'qformat_'.$fileformat);
+                if ($formatname == "[[$fileformat]]") {
+                    $formatname = $fileformat;  // Just use the raw folder name
+                }
             }
             $fileformatnames[$fileformat] = $formatname;
         }
@@ -2157,7 +2189,6 @@ class context_to_string_translator{
 
 }
 
-
 /**
  * Check capability on category
  * @param mixed $question object or id
