@@ -1,4 +1,4 @@
-<?php // $Id: lib.php,v 1.16.2.9 2008/12/14 23:40:21 jonathanharker Exp $
+<?php // $Id: lib.php,v 1.16.2.14 2010/02/18 03:11:52 mjollnir_ Exp $
 /**
  * Library functions for mnet
  *
@@ -354,12 +354,32 @@ function mnet_generate_keypair($dn = null, $days=28) {
         );
     }
 
+    $dnlimits = array(
+           'countryName'            => 2,
+           'stateOrProvinceName'    => 128,
+           'localityName'           => 128,
+           'organizationName'       => 64,
+           'organizationalUnitName' => 64,
+           'commonName'             => 64,
+           'emailAddress'           => 128
+    );
+
+    foreach ($dnlimits as $key => $length) {
+        $dn[$key] = substr($dn[$key], 0, $length);
+    }
+
     // ensure we remove trailing slashes
     $dn["commonName"] = preg_replace(':/$:', '', $dn["commonName"]);
 
-    $new_key = openssl_pkey_new();
-    $csr_rsc = openssl_csr_new($dn, $new_key, array('private_key_bits',2048));
-    $selfSignedCert = openssl_csr_sign($csr_rsc, null, $new_key, $days);
+    if (!empty($CFG->opensslcnf)) { //allow specification of openssl.cnf especially for Windows installs
+        $new_key = openssl_pkey_new(array("config" => $CFG->opensslcnf));
+        $csr_rsc = openssl_csr_new($dn, $new_key, array("config" => $CFG->opensslcnf));
+        $selfSignedCert = openssl_csr_sign($csr_rsc, null, $new_key, $days, array("config" => $CFG->opensslcnf));
+    } else {
+        $new_key = openssl_pkey_new();
+        $csr_rsc = openssl_csr_new($dn, $new_key, array('private_key_bits',2048));
+        $selfSignedCert = openssl_csr_sign($csr_rsc, null, $new_key, $days);
+    }
     unset($csr_rsc); // Free up the resource
 
     // We export our self-signed certificate to a string.
@@ -368,7 +388,11 @@ function mnet_generate_keypair($dn = null, $days=28) {
 
     // Export your public/private key pair as a PEM encoded string. You
     // can protect it with an optional passphrase if you wish.
-    $export = openssl_pkey_export($new_key, $keypair['keypair_PEM'] /* , $passphrase */);
+    if (!empty($CFG->opensslcnf)) { //allow specification of openssl.cnf especially for Windows installs
+        $export = openssl_pkey_export($new_key, $keypair['keypair_PEM'], null, array("config" => $CFG->opensslcnf));
+    } else {
+        $export = openssl_pkey_export($new_key, $keypair['keypair_PEM'] /* , $passphrase */);
+    }
     openssl_pkey_free($new_key);
     unset($new_key); // Free up the resource
 
@@ -448,9 +472,9 @@ function mnet_permit_rpc_call($includefile, $functionname, $class=false) {
             h2s.hostid in ($id_list) AND
             h2s.publish = '1'";
 
-    $permissionobj = record_exists_sql($sql);
+    $permission = count_records_sql($sql);
 
-    if ($permissionobj === false && 'dangerous' != $CFG->mnet_dispatcher_mode) {
+    if (!$permission && 'dangerous' != $CFG->mnet_dispatcher_mode) {
         return RPC_FORBIDDENMETHOD;
     }
 
