@@ -1,4 +1,4 @@
-<?php  // $Id: view.php,v 1.70.2.27 2008/11/21 07:01:00 jerome Exp $
+<?php  // $Id: view.php,v 1.70.2.33 2009/11/30 17:12:16 sam_marshall Exp $
 ///////////////////////////////////////////////////////////////////////////
 //                                                                       //
 // NOTICE OF COPYRIGHT                                                   //
@@ -296,11 +296,18 @@
     }
 
 /// Check to see if groups are being used here
-    $returnurl = 'view.php?d='.$data->id.'&amp;search='.s($search).'&amp;sort='.s($sort).'&amp;order='.s($order).'&amp;';
+    $returnurl = $CFG->wwwroot . '/mod/data/view.php?d='.$data->id.'&amp;search='.s($search).'&amp;sort='.s($sort).'&amp;order='.s($order).'&amp;';
     groups_print_activity_menu($cm, $returnurl);
     $currentgroup = groups_get_activity_group($cm);
     $groupmode = groups_get_activity_groupmode($cm);
 
+    // deletect entries not approved yet and show hint instead of not found error
+    if ($record and $data->approval and !$record->approved and $record->userid != $USER->id and !has_capability('mod/data:manageentries', $context)) {
+        if (!$currentgroup or $record->groupid == $currentgroup or $record->groupid == 0) {
+            print_error('notapproved', 'data');
+        }
+    }
+
     print_heading(format_string($data->name));
 
     // Do we need to show a link to the RSS feed for the records?
@@ -426,6 +433,11 @@
 
         $ilike = sql_ilike(); //Be case-insensitive
 
+        // Init some variables to be used by advanced search
+        $advsearchselect = '';
+        $advwhere        = '';
+        $advtables       = '';
+
     /// Find the field we are sorting on
         if ($sort <= 0 or !$sortfield = data_get_field_from_id($sort, $data)) {
 
@@ -469,9 +481,9 @@
                         $searchselect .= " AND $val->field $ilike '%{$val->data}%'";
                         continue;
                     }
-                    $tables .= ', '.$CFG->prefix.'data_content c'.$key.' ';
-                    $where .= ' AND c'.$key.'.recordid = r.id';
-                    $searchselect .= ' AND ('.$val->sql.') ';
+                    $advtables .= ', '.$CFG->prefix.'data_content c'.$key.' ';
+                    $advwhere .= ' AND c'.$key.'.recordid = r.id';
+                    $advsearchselect .= ' AND ('.$val->sql.') ';
                 }
             } else if ($search) {
                 $searchselect = " AND (cs.content $ilike '%$search%' OR u.firstname $ilike '%$search%' OR u.lastname $ilike '%$search%' ) ";
@@ -484,7 +496,7 @@
             $sortcontent = $sortfield->get_sort_field();
             $sortcontentfull = $sortfield->get_sort_sql('c.'.$sortcontent);
 
-            $what = ' DISTINCT r.id, r.approved, r.timecreated, r.timemodified, r.userid, u.firstname, u.lastname, c.'.$sortcontent.', '.$sortcontentfull.' AS _order ';
+            $what = ' DISTINCT r.id, r.approved, r.timecreated, r.timemodified, r.userid, u.firstname, u.lastname, '.sql_compare_text($sortcontentfull).' AS _order ';
             $count = ' COUNT(DISTINCT c.recordid) ';
             $tables = $CFG->prefix.'data_content c,'.$CFG->prefix.'data_records r,'.$CFG->prefix.'data_content cs, '.$CFG->prefix.'user u ';
             $where =  'WHERE c.recordid = r.id
@@ -506,9 +518,9 @@
                         $searchselect .= " AND $val->field $ilike '%{$val->data}%'";
                         continue;
                     }
-                    $tables .= ', '.$CFG->prefix.'data_content c'.$key.' ';
-                    $where .= ' AND c'.$key.'.recordid = r.id AND c'.$key.'.fieldid = '.$key;
-                    $searchselect .= ' AND ('.$val->sql.') ';
+                    $advtables .= ', '.$CFG->prefix.'data_content c'.$key.' ';
+                    $advwhere .= ' AND c'.$key.'.recordid = r.id AND c'.$key.'.fieldid = '.$key;
+                    $advsearchselect .= ' AND ('.$val->sql.') ';
                 }
             } else if ($search) {
                 $searchselect = " AND (cs.content $ilike '%$search%' OR u.firstname $ilike '%$search%' OR u.lastname $ilike '%$search%' ) ";
@@ -519,7 +531,7 @@
 
     /// To actually fetch the records
 
-        $fromsql    = "FROM $tables $where $groupselect $approveselect $searchselect";
+        $fromsql    = "FROM $tables $advtables $where $advwhere $groupselect $approveselect $searchselect $advsearchselect";
         $sqlselect  = "SELECT $what $fromsql $sortorder";
         $sqlcount   = "SELECT $count $fromsql";   // Total number of records when searching
         $sqlrids    = "SELECT tmp.id FROM ($sqlselect) tmp";
@@ -528,7 +540,7 @@
     /// Work out the paging numbers and counts
 
         $totalcount = count_records_sql($sqlcount);
-        if (empty($searchselect)) {
+        if (empty($searchselect) && empty($advsearchselect)) {
             $maxcount = $totalcount;
         } else {
             $maxcount = count_records_sql($sqlmax);
@@ -590,7 +602,9 @@
 
             if ($mode == 'single') {                  // Single template
                 $baseurl = 'view.php?d=' . $data->id . '&amp;mode=single&amp;';
-                $search && $baseurl .= 'filter=1&amp;';
+                if (!empty($search)) {
+                    $baseurl .= 'filter=1&amp;';
+                }
                 print_paging_bar($totalcount, $page, $nowperpage, $baseurl, $pagevar='page');
 
                 if (empty($data->singletemplate)){
@@ -606,6 +620,9 @@
                 $baseurl = 'view.php?d='.$data->id.'&amp;';
                 //send the advanced flag through the URL so it is remembered while paging.
                 $baseurl .= 'advanced='.$advanced.'&amp;';
+                if (!empty($search)) {
+                    $baseurl .= 'filter=1&amp;';
+                }
                 //pass variable to allow determining whether or not we are paging through results.
                 $baseurl .= 'paging='.$paging.'&amp;';
 
