@@ -1,4 +1,4 @@
-<?php  // $Id: lib.php,v 1.193.2.19 2008/11/12 17:02:23 sam_marshall Exp $
+<?php  // $Id: lib.php,v 1.193.2.22 2009/11/22 12:43:10 skodak Exp $
 
 /// Library of functions and constants for module glossary
 /// (replace glossary with the name of your module and delete this line)
@@ -161,11 +161,19 @@ function glossary_delete_instance($id) {
 }
 
 function glossary_user_outline($course, $user, $mod, $glossary) {
+    global $CFG;
 /// Return a small object with summary information about what a
 /// user has done with a given particular instance of this module
 /// Used for user activity reports.
 /// $return->time = the time they did it
 /// $return->info = a short text description
+    require_once("$CFG->libdir/gradelib.php");
+    $grades = grade_get_grades($course->id, 'mod', 'glossary', $glossary->id, $user->id);
+    if (empty($grades->items[0]->grades)) {
+        $grade = false;
+    } else {
+        $grade = reset($grades->items[0]->grades);
+    }
 
     if ($entries = glossary_get_user_entries($glossary->id, $user->id)) {
         $result = new object();
@@ -173,8 +181,18 @@ function glossary_user_outline($course, $user, $mod, $glossary) {
 
         $lastentry = array_pop($entries);
         $result->time = $lastentry->timemodified;
+
+        if ($grade) {
+            $result->info .= ', ' . get_string('grade') . ': ' . $grade->str_long_grade;
+        }
+        return $result;
+    } else if ($grade) {
+        $result = new object();
+        $result->info = get_string('grade') . ': ' . $grade->str_long_grade;
+        $result->time = $grade->dategraded;
         return $result;
     }
+
     return NULL;
 }
 
@@ -197,7 +215,16 @@ function glossary_user_complete($course, $user, $mod, $glossary) {
 /// Print a detailed representation of what a  user has done with
 /// a given particular instance of this module, for user activity reports.
     global $CFG;
+    require_once("$CFG->libdir/gradelib.php");
 
+    $grades = grade_get_grades($course->id, 'mod', 'glossary', $glossary->id, $user->id);
+    if (!empty($grades->items[0]->grades)) {
+        $grade = reset($grades->items[0]->grades);
+        echo '<p>'.get_string('grade').': '.$grade->str_long_grade.'</p>';
+        if ($grade->str_feedback) {
+            echo '<p>'.get_string('feedback').': '.$grade->str_feedback.'</p>';
+        }
+    }
     if ($entries = glossary_get_user_entries($glossary->id, $user->id)) {
         echo '<table width="95%" border="0"><tr><td>';
         foreach ($entries as $entry) {
@@ -906,7 +933,7 @@ function  glossary_print_entry_approval($cm, $entry, $mode,$align="right",$insid
         if ($insidetable) {
             echo '<table class="glossaryapproval" align="'.$align.'"><tr><td align="'.$align.'">';
         }
-        echo '<a title="'.get_string('approve','glossary').'" href="approve.php?id='.$cm->id.'&amp;eid='.$entry->id.'&amp;mode='.$mode.'"><img align="'.$align.'" src="'.$CFG->pixpath.'/i/approve.gif" style="border:0px; width:34px; height:34px" alt="'.get_string('approve','glossary').'" /></a>';
+        echo '<a title="'.get_string('approve','glossary').'" href="approve.php?eid='.$entry->id.'&amp;mode='.$mode.'&amp;sesskey='.sesskey().'"><img align="'.$align.'" src="'.$CFG->pixpath.'/i/approve.gif" style="border:0px; width:34px; height:34px" alt="'.get_string('approve','glossary').'" /></a>';
         if ($insidetable) {
             echo '</td></tr></table>';
         }
@@ -2005,7 +2032,7 @@ function glossary_get_paging_bar($totalcount, $page, $perpage, $baseurl, $maxpag
         while ($pagenum <= $pageto) {
             $pagetoshow = $pagenum +1;
             if ($pagenum == $page && !$specialselected) {
-                $code .= "$separator$pagetoshow";
+                $code .= "$separator<b>$pagetoshow</b>";
             } else {
                 $code .= "$separator<a href=\"{$baseurl}page=$pagenum\">$pagetoshow</a>";
             }
@@ -2025,7 +2052,7 @@ function glossary_get_paging_bar($totalcount, $page, $perpage, $baseurl, $maxpag
         if ($showspecial) {
             $code .= '<br />';
             if ($specialselected) {
-                $code .= $specialtext;
+                $code .= "<b>$specialtext</b>";
             } else {
                 $code .= "$separator<a href=\"{$baseurl}page=$specialvalue\">$specialtext</a>";
             }
