@@ -1,4 +1,4 @@
-<?php // $Id: mod_form.php,v 1.28.2.6 2008/12/05 04:20:32 tjhunt Exp $
+<?php // $Id: mod_form.php,v 1.28.2.11 2009/10/05 03:05:38 jerome Exp $
 require_once ($CFG->dirroot.'/course/moodleform_mod.php');
 
 require_once("$CFG->dirroot/mod/quiz/locallib.php");
@@ -140,8 +140,6 @@ class mod_quiz_mod_form extends moodleform_mod {
         $mform->setAdvanced('decimalpoints', $CFG->quiz_fix_decimalpoints);
         $mform->setDefault('decimalpoints', $CFG->quiz_decimalpoints);
 
-        $mform->addElement('hidden', 'grade', $CFG->quiz_maximumgrade);
-
 //-------------------------------------------------------------------------------
         $mform->addElement('header', 'reviewoptionshdr', get_string('reviewoptionsheading', 'quiz'));
         $mform->setHelpButton('reviewoptionshdr', array('reviewoptions', get_string('reviewoptionsheading','quiz'), 'quiz'));
@@ -196,8 +194,14 @@ class mod_quiz_mod_form extends moodleform_mod {
 //-------------------------------------------------------------------------------
         $mform->addElement('header', 'security', get_string('security', 'form'));
 
-        $mform->addElement('selectyesno', 'popup', get_string("popup", "quiz"));
-        $mform->setHelpButton('popup', array("popup", get_string("popup", "quiz"), "quiz"));
+        $options = array(
+                    0 => get_string('none', 'quiz'),
+                    1 => get_string('popupwithjavascriptsupport', 'quiz'));
+        if (!empty($CFG->enablesafebrowserintegration)) {
+            $options[2] = get_string('requiresafeexambrowser', 'quiz');
+        }
+        $mform->addElement('select', 'popup', get_string('browsersecurity', 'quiz'), $options);
+        $mform->setHelpButton('popup', array('browsersecurity', get_string('browsersecurity', 'quiz'), 'quiz'));
         $mform->setAdvanced('popup', $CFG->quiz_fix_popup);
         $mform->setDefault('popup', $CFG->quiz_popup);
 
@@ -223,11 +227,25 @@ class mod_quiz_mod_form extends moodleform_mod {
         $mform->addElement('header', 'overallfeedbackhdr', get_string('overallfeedback', 'quiz'));
         $mform->setHelpButton('overallfeedbackhdr', array('overallfeedback', get_string('overallfeedback', 'quiz'), 'quiz'));
 
+        $mform->addElement('hidden', 'grade', $CFG->quiz_maximumgrade);
+        $mform->setType('grade', PARAM_RAW);
+        if (empty($this->_cm)) {
+            $needwarning = $CFG->quiz_maximumgrade == 0;
+        } else {
+            $quizgrade = get_field('quiz', 'grade', 'id', $this->_instance);
+            $needwarning = $quizgrade == 0;
+        }
+        if ($needwarning) {
+            $mform->addElement('static', 'nogradewarning', '', get_string('nogradewarning', 'quiz'));
+        }
+
         $mform->addElement('static', 'gradeboundarystatic1', get_string('gradeboundary', 'quiz'), '100%');
 
-        $repeatarray=array();
+        $repeatarray = array();
         $repeatarray[] = &MoodleQuickForm::createElement('text', 'feedbacktext', get_string('feedback', 'quiz'), array('size' => 50));
+        $mform->setType('feedbacktext', PARAM_RAW);
         $repeatarray[] = &MoodleQuickForm::createElement('text', 'feedbackboundaries', get_string('gradeboundary', 'quiz'), array('size' => 10));
+        $mform->setType('feedbackboundaries', PARAM_NOTAGS);
 
         if (!empty($this->_instance)) {
             $this->_feedbacks = get_records('quiz_feedback', 'quizid', $this->_instance, 'mingrade DESC');
@@ -236,20 +254,24 @@ class mod_quiz_mod_form extends moodleform_mod {
         }
         $numfeedbacks = max(count($this->_feedbacks) * 1.5, 5);
 
-        $mform->setType('feedbacktext', PARAM_RAW);
-        $mform->setType('feedbackboundaries', PARAM_NOTAGS);
-
-        $nextel=$this->repeat_elements($repeatarray, $numfeedbacks-1,
+        $nextel = $this->repeat_elements($repeatarray, $numfeedbacks - 1,
                 array(), 'boundary_repeats', 'boundary_add_fields', 3,
                 get_string('addmoreoverallfeedbacks', 'quiz'), true);
 
-        //put some extra elements in before the button
+        // Put some extra elements in before the button
         $insertEl = &MoodleQuickForm::createElement('text', "feedbacktext[$nextel]", get_string('feedback', 'quiz'), array('size' => 50));
         $mform->insertElementBefore($insertEl, 'boundary_add_fields');
 
         $insertEl = &MoodleQuickForm::createElement('static', 'gradeboundarystatic2', get_string('gradeboundary', 'quiz'), '0%');
         $mform->insertElementBefore($insertEl, 'boundary_add_fields');
 
+        // Add the disabledif rules. We cannot do this using the $repeatoptions parameter to
+        // repeat_elements becuase we don't want to dissable the first feedbacktext.
+        for ($i = 0; $i < $nextel; $i++) {
+            $mform->disabledIf('feedbackboundaries[' . $i . ']', 'grade', 'eq', 0);
+            $mform->disabledIf('feedbacktext[' . ($i + 1) . ']', 'grade', 'eq', 0);
+        }
+
 //-------------------------------------------------------------------------------
         // buttons
         $this->add_action_buttons();
@@ -342,12 +364,14 @@ class mod_quiz_mod_form extends moodleform_mod {
         $numboundaries = $i;
 
         // Check there is nothing in the remaining unused fields.
-        for ($i = $numboundaries; $i < count($data['feedbackboundaries'] ); $i += 1) {
-            if (!empty($data['feedbackboundaries'][$i] ) && trim($data['feedbackboundaries'][$i] ) != '') {
-                $errors["feedbackboundaries[$i]"] = get_string('feedbackerrorjunkinboundary', 'quiz', $i + 1);
+        if (!empty($data['feedbackboundaries'])) {
+            for ($i = $numboundaries; $i < count($data['feedbackboundaries']); $i += 1) {
+                if (!empty($data['feedbackboundaries'][$i] ) && trim($data['feedbackboundaries'][$i] ) != '') {
+                    $errors["feedbackboundaries[$i]"] = get_string('feedbackerrorjunkinboundary', 'quiz', $i + 1);
+                }
             }
         }
-        for ($i = $numboundaries + 1; $i < count($data['feedbacktext'] ); $i += 1) {
+        for ($i = $numboundaries + 1; $i < count($data['feedbacktext']); $i += 1) {
             if (!empty($data['feedbacktext'][$i] ) && trim($data['feedbacktext'][$i] ) != '') {
                 $errors["feedbacktext[$i]"] = get_string('feedbackerrorjunkinfeedback', 'quiz', $i + 1);
             }
