@@ -2,7 +2,7 @@
 /**
  * This script lists student attempts
  *
- * @version $Id: report.php,v 1.98.2.46 2009/01/14 07:03:15 tjhunt Exp $
+ * @version $Id: report.php,v 1.98.2.52 2010/04/30 13:15:40 tjhunt Exp $
  * @author Martin Dougiamas, Tim Hunt and others.
  * @license http://www.gnu.org/copyleft/gpl.html GNU Public License
  * @package quiz
@@ -21,7 +21,6 @@ class quiz_report extends quiz_default_report {
         // Define some strings
         $strreallydel  = addslashes(get_string('deleteattemptcheck','quiz'));
         $strtimeformat = get_string('strftimedatetime');
-        $strreviewquestion = get_string('reviewresponse', 'quiz');
 
         $context = get_context_instance(CONTEXT_MODULE, $cm->id);
 
@@ -30,20 +29,6 @@ class quiz_report extends quiz_default_report {
             $this->print_header_and_tabs($cm, $course, $quiz, "overview");
         }
 
-        if($attemptids = optional_param('attemptid', array(), PARAM_INT)) {
-            //attempts need to be deleted
-            require_capability('mod/quiz:deleteattempts', $context);
-            $attemptids = optional_param('attemptid', array(), PARAM_INT);
-            foreach($attemptids as $attemptid) {
-                add_to_log($course->id, 'quiz', 'delete attempt', 'report.php?id=' . $cm->id,
-                        $attemptid, $cm->id);
-                quiz_delete_attempt($attemptid, $quiz);
-            }
-            //No need for a redirect, any attemptids that do not exist are ignored.
-            //So no problem if the user refreshes and tries to delete the same attempts
-            //twice.
-        }
-
         // Work out some display options - whether there is feedback, and whether scores should be shown.
         $hasfeedback = quiz_has_feedback($quiz->id) && $quiz->grade > 1.e-7 && $quiz->sumgrades > 1.e-7;
         $fakeattempt = new stdClass();
@@ -119,7 +104,7 @@ class quiz_report extends quiz_default_report {
             }
         }
         $nostudents = false;
-        if (!$students = get_users_by_capability($context, array('mod/quiz:reviewmyattempts', 'mod/quiz:attempt'),'','','','','','',false)){
+        if (!$students = get_users_by_capability($context, array('mod/quiz:reviewmyattempts', 'mod/quiz:attempt'),'id,1','','','','','',false)){
             notify(get_string('nostudentsyet'));
             $nostudents = true;
             $studentslist = '';
@@ -130,10 +115,11 @@ class quiz_report extends quiz_default_report {
         if (empty($currentgroup)) {
             // all users who can attempt quizzes
             $groupstudentslist = '';
+            $groupstudents = array();
             $allowedlist = $studentslist;
         } else {
             // all users who can attempt quizzes and who are in the currently selected group
-            if (!$groupstudents = get_users_by_capability($context, 'mod/quiz:attempt','','','','',$currentgroup,'',false)){
+            if (!$groupstudents = get_users_by_capability($context, array('mod/quiz:reviewmyattempts', 'mod/quiz:attempt'),'id,1','','','',$currentgroup,'',false)){
                 notify(get_string('nostudentsingroup'));
                 $nostudents = true;
                 $groupstudents = array();
@@ -142,6 +128,23 @@ class quiz_report extends quiz_default_report {
             $allowedlist = $groupstudentslist;
         }
 
+        if ($students && ($attemptids = optional_param('attemptid', array(), PARAM_INT)) && confirm_sesskey()) {
+            //attempts need to be deleted
+            require_capability('mod/quiz:deleteattempts', $context);
+            foreach ($attemptids as $attemptid) {
+                $attempt = get_record('quiz_attempts', 'id', $attemptid);
+                if ($groupstudents && !in_array($attempt->userid, $groupstudents)) {
+                    continue;
+                }
+                add_to_log($course->id, 'quiz', 'delete attempt', 'report.php?id=' . $cm->id,
+                        $attemptid, $cm->id);
+                quiz_delete_attempt($attempt, $quiz);
+            }
+            //No need for a redirect, any attemptids that do not exist are ignored.
+            //So no problem if the user refreshes and tries to delete the same attempts
+            //twice.
+        }
+
         if (!$nostudents || ($attemptsmode == QUIZ_REPORT_ATTEMPTS_ALL)){
     
             // Print information on the grading method and whether we are displaying
@@ -201,6 +204,7 @@ class quiz_report extends quiz_default_report {
                     // Ignore questions of zero length
                     $columns[] = 'qsgrade'.$id;
                     $headers[] = '#'.$question->number;
+                    $question->formattedname = strip_tags(format_string($question->name));
                 }
             }
     
@@ -337,8 +341,9 @@ class quiz_report extends quiz_default_report {
                     "END) AS gradedattempt, ";
             }
             
-            $select .='qa.uniqueid AS attemptuniqueid, qa.id AS attempt, u.id AS userid, u.idnumber, u.firstname, u.lastname, u.picture, '.
-                'qa.sumgrades, qa.timefinish, qa.timestart, qa.timefinish - qa.timestart AS duration ';
+            $select .= 'qa.uniqueid AS attemptuniqueid, qa.id AS attempt, ' . 
+                    'u.id AS userid, u.idnumber, u.firstname, u.lastname, u.picture, u.imagealt, ' .
+                    'qa.sumgrades, qa.timefinish, qa.timestart, qa.timefinish - qa.timestart AS duration ';
     
             // This part is the same for all cases - join users and quiz_attempts tables
             $from = 'FROM '.$CFG->prefix.'user u ';
@@ -459,15 +464,16 @@ class quiz_report extends quiz_default_report {
                         }
                     }
                     if (in_array('picture', $columns)){
-                        $picture = print_user_picture($attempt->userid, $course->id, $attempt->picture, false, true);
+                        $attempt->id = $attempt->userid;
+                        $picture = print_user_picture($attempt, $course->id, NULL, false, true);
                         $row[] = $picture;
                     }
                     if (!$download){
                         $userlink = '<a href="'.$CFG->wwwroot.'/user/view.php?id='.$attempt->userid.
-                                '&amp;course='.$course->id.'">'.fullname($attempt).'</a>';
+                                '&amp;course='.$course->id.'">'.fullname($attempt,has_capability('moodle/site:viewfullnames', $context)).'</a>';
                         $row[] = $userlink;
                     } else {
-                        $row[] = fullname($attempt);
+                        $row[] = fullname($attempt, has_capability('moodle/site:viewfullnames', $context));
                     }
                     
                     if (in_array('idnumber', $columns)){
@@ -537,7 +543,7 @@ class quiz_report extends quiz_default_report {
                                     $grade = $grade.'/'.quiz_rescale_grade($question->grade, $quiz);
                                     $row[] = link_to_popup_window('/mod/quiz/reviewquestion.php?state='.
                                             $stateforqinattempt->id.'&amp;number='.$question->number,
-                                            'reviewquestion', $grade, 450, 650, $strreviewquestion, 'none', true);
+                                            'reviewquestion', $grade, 450, 650, get_string('reviewresponsetoq', 'quiz', $question->formattedname), 'none', true);
                                 } else {
                                     $row[] = $grade;
                                 }
@@ -582,7 +588,7 @@ class quiz_report extends quiz_default_report {
                         $groupaveragerow = array('fullname' => get_string('groupavg', 'grades'),
                                 'sumgrades' => round($groupaverage->grade, $quiz->decimalpoints),
                                 'feedbacktext'=> quiz_report_feedback_for_grade($groupaverage->grade, $quiz->id));
-                        if($detailedmarks && $qmsubselect) {
+                        if($detailedmarks && ($qmsubselect || $quiz->attempts == 1)) {
                             $avggradebyq = quiz_get_average_grade_for_questions($quiz, $groupstudentslist);
                             $groupaveragerow += quiz_format_average_grade_for_questions($avggradebyq, $questions, $quiz, $download);
                         }
@@ -592,7 +598,7 @@ class quiz_report extends quiz_default_report {
                     $overallaveragerow = array('fullname' => get_string('overallaverage', 'grades'),
                                 'sumgrades' => round($overallaverage->grade, $quiz->decimalpoints),
                                 'feedbacktext'=> quiz_report_feedback_for_grade($overallaverage->grade, $quiz->id));
-                    if($detailedmarks && $qmsubselect) {
+                    if($detailedmarks && ($qmsubselect || $quiz->attempts == 1)) {
                         $avggradebyq = quiz_get_average_grade_for_questions($quiz, $studentslist);
                         $overallaveragerow += quiz_format_average_grade_for_questions($avggradebyq, $questions, $quiz, $download);
                     }
@@ -605,6 +611,7 @@ class quiz_report extends quiz_default_report {
                             '" onsubmit="return confirm(\''.$strreallydel.'\');">';
                     echo '<div style="display: none;">';
                     echo $reporturlwithdisplayoptions->hidden_params_out();
+                    echo '<input type="hidden" name="sesskey" value="' . sesskey() . '">';
                     echo '</div>';
                     echo '<div>';
     
@@ -664,7 +671,7 @@ class quiz_report extends quiz_default_report {
             $mform->set_data($displayoptions +compact('detailedmarks', 'pagesize'));
             $mform->display();
             //should be quicker than a COUNT to test if there is at least one record :
-            if ($showgrades && get_records('quiz_grades', 'quiz', $quiz->id, '', '*', 0, 1)){
+            if ($showgrades && record_exists('quiz_grades', 'quiz', $quiz->id)){
                 $imageurl = $CFG->wwwroot.'/mod/quiz/report/overview/overviewgraph.php?id='.$quiz->id;
                 print_heading(get_string('overviewreportgraph', 'quiz_overview'));
                 echo '<div class="mdl-align"><img src="'.$imageurl.'" alt="'.get_string('overviewreportgraph', 'quiz_overview').'" /></div>';
