@@ -1,4 +1,4 @@
-<?php // $Id: aicclib.php,v 1.5.2.9 2008/12/22 07:04:37 danmarsden Exp $
+<?php // $Id: aicclib.php,v 1.5.2.14 2010/03/12 07:39:09 danmarsden Exp $
 function scorm_add_time($a, $b) {
     $aes = explode(':',$a);
     $bes = explode(':',$b);
@@ -215,10 +215,10 @@ function scorm_parse_aicc($pkgdir,$scormid) {
 
             //print_r($sco);
             if (get_record('scorm_scoes','scorm',$scormid,'identifier',$sco->identifier)) {
-                $id = update_record('scorm_scoes',$sco);
+                $id = update_record('scorm_scoes',addslashes_recursive($sco));
                 unset($oldscoes[$id]);
             } else {
-                $id = insert_record('scorm_scoes',$sco);
+                $id = insert_record('scorm_scoes',addslashes_recursive($sco));
             }
 
             if ($launch == 0) {
@@ -245,11 +245,13 @@ function scorm_parse_aicc($pkgdir,$scormid) {
                         $id = null;
                         if ($oldscoid = scorm_array_search('identifier',$sco->identifier,$oldscoes)) {
                             $sco->id = $oldscoid;
-                            $id = update_record('scorm_scoes',$sco);
+                            if(update_record('scorm_scoes',addslashes_recursive($sco))) {
+                                $id = $oldscoid;
+                            }
                             delete_records('scorm_scoes_data','scoid',$oldscoid);
                             unset($oldscoes[$oldscoid]);
                         } else {
-                            $id = insert_record('scorm_scoes',$sco);
+                            $id = insert_record('scorm_scoes',addslashes_recursive($sco));
                         }
                         if (!empty($id)) {
                             unset($scodata);
@@ -257,32 +259,32 @@ function scorm_parse_aicc($pkgdir,$scormid) {
                             if (isset($element->web_launch)) {
                                 $scodata->name = 'parameters';
                                 $scodata->value = $element->web_launch;
-                                $dataid = insert_record('scorm_scoes_data',$scodata);
+                                $dataid = insert_record('scorm_scoes_data',addslashes_recursive($scodata));
                             }
                             if (isset($element->prerequisites)) {
                                 $scodata->name = 'prerequisites';
                                 $scodata->value = $element->prerequisites;
-                                $dataid = insert_record('scorm_scoes_data',$scodata);
+                                $dataid = insert_record('scorm_scoes_data',addslashes_recursive($scodata));
                             }
                             if (isset($element->max_time_allowed)) {
                                 $scodata->name = 'max_time_allowed';
                                 $scodata->value = $element->max_time_allowed;
-                                $dataid = insert_record('scorm_scoes_data',$scodata);
+                                $dataid = insert_record('scorm_scoes_data',addslashes_recursive($scodata));
                             }
                             if (isset($element->time_limit_action)) {
                                 $scodata->name = 'time_limit_action';
                                 $scodata->value = $element->time_limit_action;
-                                $dataid = insert_record('scorm_scoes_data',$scodata);
+                                $dataid = insert_record('scorm_scoes_data',addslashes_recursive($scodata));
                             }
                             if (isset($element->mastery_score)) {
                                 $scodata->name = 'mastery_score';
                                 $scodata->value = $element->mastery_score;
-                                $dataid = insert_record('scorm_scoes_data',$scodata);
+                                $dataid = insert_record('scorm_scoes_data',addslashes_recursive($scodata));
                             }
                             if (isset($element->core_vendor)) {
                                 $scodata->name = 'datafromlms';
                                 $scodata->value = eregi_replace('<cr>', "\r\n", $element->core_vendor);
-                                $dataid = insert_record('scorm_scoes_data',$scodata);
+                                $dataid = insert_record('scorm_scoes_data',addslashes_recursive($scodata));
                             }
                         }
                         if ($launch==0) {
@@ -342,6 +344,9 @@ function scorm_get_toc($user,$scorm,$liststyle,$currentorg='',$scoid='',$mode='n
         $usertracks = array();
         foreach ($scoes as $sco) {
             if (!empty($sco->launch)) {
+                if (empty($scoid)) {
+                    $scoid = $sco->id;
+                }
                 if ($usertrack = scorm_get_tracks($sco->id,$user->id,$attempt)) {
                     if ($usertrack->status == '') {
                         $usertrack->status = 'notattempted';
