@@ -1,4 +1,4 @@
-<?php  // $Id: lib.php,v 1.87.2.13 2008/11/14 00:14:50 piers Exp $
+<?php  // $Id: lib.php,v 1.87.2.17 2010/04/21 23:40:03 danmarsden Exp $
 
 /**
 * Given an object containing all the necessary data,
@@ -219,10 +219,16 @@ function scorm_delete_instance($id) {
 function scorm_user_outline($course, $user, $mod, $scorm) { 
     global $CFG;
     require_once('locallib.php');
-
-    $return = scorm_grade_user($scorm, $user->id, true);
-
-    return $return;
+    require_once("$CFG->libdir/gradelib.php");
+    $grades = grade_get_grades($course->id, 'mod', 'scorm', $scorm->id, $user->id);
+    if (!empty($grades->items[0]->grades)) {
+        $grade = reset($grades->items[0]->grades);
+        $result = new object();
+        $result->info = get_string('grade') . ': '. $grade->str_long_grade;
+        $result->time = $grade->dategraded;
+        return $result;
+    }
+    return null;
 }
 
 /**
@@ -237,6 +243,8 @@ function scorm_user_outline($course, $user, $mod, $scorm) {
 */
 function scorm_user_complete($course, $user, $mod, $scorm) {
     global $CFG;
+    require_once("$CFG->libdir/gradelib.php");
+    require_once("locallib.php");
 
     $liststyle = 'structlist';
     $scormpixdir = $CFG->modpixpath.'/scorm/pix';
@@ -245,7 +253,21 @@ function scorm_user_complete($course, $user, $mod, $scorm) {
     $lastmodify = 0;
     $sometoreport = false;
     $report = '';
+
+    // First Access and Last Access dates for SCOs
+    $timetracks = scorm_get_sco_runtime($scorm->id, false, $user->id);
+    $firstmodify = $timetracks->start;
+    $lastmodify = $timetracks->finish;
     
+    $grades = grade_get_grades($course->id, 'mod', 'scorm', $scorm->id, $user->id);
+    if (!empty($grades->items[0]->grades)) {
+        $grade = reset($grades->items[0]->grades);
+        echo '<p>'.get_string('grade').': '.$grade->str_long_grade.'</p>';
+        if ($grade->str_feedback) {
+            echo '<p>'.get_string('feedback').': '.$grade->str_feedback.'</p>';
+        }
+    }
+
     if ($orgs = get_records_select('scorm_scoes',"scorm='$scorm->id' AND organization='' AND launch=''",'id','id,identifier,title')) {
         if (count($orgs) <= 1) {
             unset($orgs);
@@ -302,7 +324,6 @@ function scorm_user_complete($course, $user, $mod, $scorm) {
                     }
 
                     if ($sco->launch) {
-                        require_once('locallib.php');
                         $score = '';
                         $totaltime = '';
                         if ($usertrack=scorm_get_tracks($sco->id,$user->id)) {
@@ -311,14 +332,6 @@ function scorm_user_complete($course, $user, $mod, $scorm) {
                             }
                             $strstatus = get_string($usertrack->status,'scorm');
                             $report .= "<img src='".$scormpixdir.'/'.$usertrack->status.".gif' alt='$strstatus' title='$strstatus' />";
-                            if ($usertrack->timemodified != 0) {
-                                if ($usertrack->timemodified > $lastmodify) {
-                                    $lastmodify = $usertrack->timemodified;
-                                }
-                                if ($usertrack->timemodified < $firstmodify) {
-                                    $firstmodify = $usertrack->timemodified;
-                                }
-                            }
                         } else {
                             if ($sco->scormtype == 'sco') {
                                 $report .= '<img src="'.$scormpixdir.'/'.'notattempted.gif" alt="'.get_string('notattempted','scorm').'" title="'.get_string('notattempted','scorm').'" />';
@@ -387,7 +400,7 @@ function scorm_cron () {
     }
 
     $timenow = time();
-    $updatetime = usergetmidnight($timenow, $sitetimezone) + ($CFG->scorm_updatetime * 3600);
+    $updatetime = usergetmidnight($timenow, $sitetimezone) + ($CFG->scorm_updatetimelast * 3600);
 
     if ($CFG->scorm_updatetimelast < $updatetime and $timenow > $updatetime) {
 
@@ -643,4 +656,12 @@ function scorm_get_extra_capabilities() {
     return array('moodle/site:accessallgroups');
 }
 
-?>
\ No newline at end of file
+/**
+ * Tells if files in moddata are trusted and can be served without XSS protection.
+ * @return bool true if file can be submitted by teacher only (trusted), false otherwise
+ */
+function scorm_is_moddata_trusted() {
+    return true;
+}
+
+?>
