@@ -1,4 +1,4 @@
-<?php  // $Id: lib.php,v 1.53.2.5 2008/09/26 09:33:03 stronk7 Exp $
+<?php  // $Id: lib.php,v 1.53.2.9 2010/01/21 23:40:02 stronk7 Exp $
 
 /// Library of functions and constants for module wiki
 /// (replace wiki with the name of your module and delete this line)
@@ -237,13 +237,6 @@ function wiki_cron () {
     return $result;
 }
 
-function wiki_grades($wikiid) {
-/// Must return an array of grades for a given instance of this module,
-/// indexed by user.  It also returns a maximum allowed grade.
-
-    return NULL;
-}
-
 function wiki_get_participants($wikiid) {
 //Returns the users with data in one wiki
 //(users with records in wiki_pages and wiki_entries)
@@ -996,11 +989,13 @@ function wiki_can_add_entry(&$wiki, &$user, &$course, $userid=0, $groupid=0) {
         else if ($groupid == 0) {
             return ($mygroupid != 0 and wiki_is_teacher($wiki));
         }
-        /// If there is a group mode, non-editing teachers with an assigned group, can only create wikis
-        /// in their group. Non-editing teachers with no assigned group and editing teachers can create any wiki.
+        /// If requesting a group, must be an editing teacher, a non-editing teacher with no assigned group,
+        /// or a non-editing teacher requesting their group. or a student in group, but wiki is empty.
         else {
             return (wiki_is_teacheredit($wiki) or
-                    (wiki_is_teacher($wiki) and ($mygroupid == 0 or @in_array($groupid, $mygroupid))));
+                    (wiki_is_teacher($wiki) and ($mygroupid == 0 or @in_array($groupid, $mygroupid))) or
+                    (wiki_is_student($wiki, $user->id) and @in_array($groupid, $mygroupid))
+                    );
         }
         break;
     }
