@@ -1,4 +1,4 @@
-<?php  // $Id: questiontype.php,v 1.26.2.12 2008/12/04 16:32:16 pichetp Exp $
+<?php  // $Id: questiontype.php,v 1.26.2.18 2010/04/29 10:41:53 tjhunt Exp $
 
 /////////////////
 // CALCULATED ///
@@ -122,6 +122,10 @@ class question_calculated_qtype extends question_dataset_dependent_questiontype
         // Get old answers:
         global $CFG;
 
+        if (isset($question->answer) && !isset($question->answers)) {
+            $question->answers = $question->answer;
+        }
+
         // Get old versions of the objects
         if (!$oldanswers = get_records('question_answers', 'question', $question->id, 'id ASC')) {
             $oldanswers = array();
@@ -130,8 +134,8 @@ class question_calculated_qtype extends question_dataset_dependent_questiontype
         if (!$oldoptions = get_records('question_calculated', 'question', $question->id, 'answer ASC')) {
             $oldoptions = array();
         }
-                // Save the units.
-        // Save units
+
+        // Save the units.
         $virtualqtype = $this->get_virtual_qtype();
         $result = $virtualqtype->save_numerical_units($question);
         if (isset($result->error)) {
@@ -664,8 +668,19 @@ class question_calculated_qtype extends question_dataset_dependent_questiontype
                 }
                 // echo "<pre>"; print_r($datasetdefs[$defid]->items);
                 for ($numberadded =$maxnumber+1 ; $numberadded <= $maxnumber+$numbertoadd ; $numberadded++){
-                    if (isset($datasetdefs[$defid]->items[$numberadded]) && ! $regenerate ){
-                        //  echo "<p>Reuse an previously used record".$numberadded."id".$datasetdef->id."</p>";
+                    if (isset($datasetdefs[$defid]->items[$numberadded])  ){
+	                    	// in case of regenerate it modifies the already existing record
+	                    	if ( $regenerate ) {
+		                        $datasetitem = new stdClass;
+		                        $datasetitem->id = $datasetdefs[$defid]->items[$numberadded]->id;
+		                        $datasetitem->definition = $datasetdef->id ;
+		                        $datasetitem->itemnumber = $numberadded;
+		                    		$datasetitem->value = $this->generate_dataset_item($datasetdef->options);
+						                if (!update_record('question_dataset_items', $datasetitem)) {
+						                    error("Error: Unable to update dataset item");
+						                }
+					              }
+				              //if not regenerate do nothing as there is already a record
                     } else {
                         $datasetitem = new stdClass;
                         $datasetitem->definition = $datasetdef->id ;
@@ -901,9 +916,7 @@ class question_calculated_qtype extends question_dataset_dependent_questiontype
                     FROM {$CFG->prefix}question_datasets d,
                          {$CFG->prefix}question_dataset_definitions i
                   WHERE i.id = d.datasetdefinition
-                    AND i.category = '$form->category'
-                    ;
-                   ";
+                    AND i.category = '$form->category'"; //CQU - patch because of invalid char MDL-22241 on moodle tracker
              if ($records = get_records_sql($sql)) {
                    foreach ($records as $r) {
                        if ( !isset ($datasetdefs["$r->name"])) $datasetdefs["$r->name"] = $r->itemcount;
@@ -938,8 +951,7 @@ class question_calculated_qtype extends question_dataset_dependent_questiontype
                     FROM {$CFG->prefix}question_datasets d,
                          {$CFG->prefix}question_dataset_definitions i
                     WHERE i.id = d.datasetdefinition
-                    AND i.category = $category;
-                    " ;
+                    AND i.category = $category"; //CQU - patch because of invalid char MDL-22241 on moodle tracker
             if ($records = get_records_sql($sql)) {
                 foreach ($records as $r) {
                     $sql1 = "SELECT q.*
