@@ -1,4 +1,4 @@
-<?php  // $Id: questiontype.php,v 1.41.2.16 2009/01/26 01:27:16 pichetp Exp $
+<?php  // $Id: questiontype.php,v 1.41.2.21 2010/01/14 21:56:42 pichetp Exp $
 
 ///////////////////
 /// MULTIANSWER /// (Embedded - cloze)
@@ -157,7 +157,6 @@ class embedded_cloze_qtype extends default_questiontype {
             $question->id = $authorizedquestion->id;
         }
 
-
         $question->category = $authorizedquestion->category;
         $form->course = $course; // To pass the course object to
                                  // save_question_options, where it is
@@ -314,7 +313,7 @@ class embedded_cloze_qtype extends default_questiontype {
                             }
                         }
                     }
-                    if ($correctanswer) {
+                    if ($correctanswer  != '') {
                         $feedback = '<div class="correctness">';
                         $feedback .= get_string('correctansweris', 'quiz', s($correctanswer, true));
                         $feedback .= '</div>';
@@ -346,7 +345,7 @@ class embedded_cloze_qtype extends default_questiontype {
 
                 // Set up a default chosenanswer so that all non-empty wrong
                 // answers are highlighted red
-                if (empty($chosenanswer) && !empty($response)) {
+                if (empty($chosenanswer) && $response != '') {
                     $chosenanswer = new stdClass;
                     $chosenanswer->fraction = 0.0;
                 }
