@@ -1,4 +1,4 @@
-<?php  // $Id: questiontype.php,v 1.74.2.20 2009/01/16 04:47:36 tjhunt Exp $
+<?php  // $Id: questiontype.php,v 1.74.2.31 2010/02/23 14:31:09 tjhunt Exp $
 /**
  * The default questiontype class.
  *
@@ -229,22 +229,28 @@ class default_questiontype {
     }
 
     /**
-    * Saves or updates a question after editing by a teacher
+    * Saves (creates or updates) a question.
     *
     * Given some question info and some data about the answers
     * this function parses, organises and saves the question
     * It is used by {@link question.php} when saving new data from
     * a form, and also by {@link import.php} when importing questions
     * This function in turn calls {@link save_question_options}
-    * to save question-type specific options
-    * @param object $question the question object which should be updated
-    * @param object $form the form submitted by the teacher
-    * @param object $course the course we are in
+    * to save question-type specific data.
+    *
+    * Whether we are saving a new question or updating an existing one can be
+    * determined by testing !empty($question->id). If it is not empty, we are updating.
+    *
+    * The question will be saved in category $form->category.
+    *
+    * @param object $question the question object which should be updated. For a new question will be mostly empty.
+    * @param object $form the object containing the information to save, as if from the question editing form.
+    * @param object $course not really used any more.
     * @return object On success, return the new question object. On failure,
     *       return an object as follows. If the error object has an errors field,
     *       display that as an error message. Otherwise, the editing form will be
     *       redisplayed with validation errors, from validation_errors field, which
-    *       is itself an object, shown next to the form fields.
+    *       is itself an object, shown next to the form fields. (I don't think this is accurate any more.)
     */
     function save_question($question, $form, $course) {
         global $USER;
@@ -253,15 +259,15 @@ class default_questiontype {
         // question types.
 
         // First, save the basic question itself
-        $question->name               = trim($form->name);
-        $question->questiontext       = trim($form->questiontext);
+        $question->name = trim($form->name);
+        $question->questiontext = trim($form->questiontext);
         $question->questiontextformat = $form->questiontextformat;
-        $question->parent             = isset($form->parent)? $form->parent : 0;
+        $question->parent = isset($form->parent) ? $form->parent : 0;
         $question->length = $this->actual_number_of_questions($question);
         $question->penalty = isset($form->penalty) ? $form->penalty : 0;
 
         if (empty($form->image)) {
-            $question->image = "";
+            $question->image = '';
         } else {
             $question->image = $form->image;
         }
@@ -287,33 +293,18 @@ class default_questiontype {
             $question->defaultgrade = $form->defaultgrade;
         }
 
-        if (!empty($question->id) && !empty($form->categorymoveto)) { // Question already exists
-            list($movetocategory, $movetocontextid) = explode(',', $form->categorymoveto);
-            if ($movetocategory != $question->category){
-                question_require_capability_on($question, 'move');
-                $question->category = $movetocategory;
-                //don't need to test add permission of category we are moving question to.
-                //Only categories that we have permission to add
-                //a question to will get through the form cleaning code for the select box.
-            }
-            // keep existing unique stamp code
-            $question->stamp = get_field('question', 'stamp', 'id', $question->id);
+        list($question->category) = explode(',', $form->category);
+
+        if (!empty($question->id)) {
+        /// Question already exists, update.
             $question->modifiedby = $USER->id;
             $question->timemodified = time();
             if (!update_record('question', $question)) {
                 error('Could not update question!');
             }
-        } else {         // Question is a new one
-            if (isset($form->categorymoveto)){
-                // Doing save as new question, and we have move rights.
-                list($question->category, $notused) = explode(',', $form->categorymoveto);
-                //don't need to test add permission of category we are moving question to.
-                //Only categories that we have permission to add
-                //a question to will get through the form cleaning code for the select box.
-            } else {
-                // Really a new question.
-                list($question->category, $notused) = explode(',', $form->category);
-            }
+
+        } else {
+        /// New question.
             // Set the unique code
             $question->stamp = make_unique_id_code();
             $question->createdby = $USER->id;
@@ -321,13 +312,11 @@ class default_questiontype {
             $question->timecreated = time();
             $question->timemodified = time();
             if (!$question->id = insert_record('question', $question)) {
-                print_object($question);
                 error('Could not insert new question!');
             }
         }
 
         // Now to save all the answers and type-specific options
-
         $form->id = $question->id;
         $form->qtype = $question->qtype;
         $form->category = $question->category;
@@ -749,13 +738,16 @@ class default_questiontype {
     }
 
     // Used by the following function, so that it only returns results once per quiz page.
-    var $already_done = false;
+    var $htmlheadalreadydone = false; // no private in 1.9 yet!
     /**
      * If this question type requires extra CSS or JavaScript to function,
      * then this method will return an array of <link ...> tags that reference
      * those stylesheets. This function will also call require_js()
      * from ajaxlib.php, to get any necessary JavaScript linked in too.
      *
+     * Remember that there may be more than one question of this type on a page.
+     * try to avoid including JS and CSS more than once.
+     *
      * The two parameters match the first two parameters of print_question.
      *
      * @param object $question The question object.
@@ -766,20 +758,55 @@ class default_questiontype {
      * integer array keys, which have no significance.
      */
     function get_html_head_contributions(&$question, &$state) {
+        // We only do this once for this question type, no matter how often this
+        // method is called on one page.
+        if ($this->htmlheadalreadydone) {
+            return array();
+        }
+        $this->htmlheadalreadydone = true;
+
         // By default, we link to any of the files styles.css, styles.php,
         // script.js or script.php that exist in the plugin folder.
         // Core question types should not use this mechanism. Their styles
         // should be included in the standard theme.
+        return $this->find_standard_scripts_and_css();
+    }
 
-        // We only do this once
-        // for this question type, no matter how often this method is called.
-        if ($this->already_done) {
-            return array();
-        }
-        $this->already_done = true;
+    /**
+     * Like @see{get_html_head_contributions}, but this method is for CSS and
+     * JavaScript required on the question editing page question/question.php.
+     *
+     * @return an array of bits of HTML to add to the head of pages where
+     * this question is print_question-ed in the body. The array should use
+     * integer array keys, which have no significance.
+     */
+    function get_editing_head_contributions() {
+        // By default, we link to any of the files styles.css, styles.php,
+        // script.js or script.php that exist in the plugin folder.
+        // Core question types should not use this mechanism. Their styles
+        // should be included in the standard theme.
+        return $this->find_standard_scripts_and_css();
+    }
 
+    /**
+     * Utility method used by @see{get_html_head_contributions} and
+     * @see{get_editing_head_contributions}. This looks for any of the files
+     * styles.css, styles.php, script.js or script.php that exist in the plugin
+     * folder and ensures they get included.
+     *
+     * @return array as required by get_html_head_contributions or get_editing_head_contributions.
+     */
+    function find_standard_scripts_and_css() {
         $plugindir = $this->plugin_dir();
         $baseurl = $this->plugin_baseurl();
+
+        if (file_exists($plugindir . '/script.js')) {
+            require_js($baseurl . '/script.js');
+        }
+        if (file_exists($plugindir . '/script.php')) {
+            require_js($baseurl . '/script.php');
+        }
+
         $stylesheets = array();
         if (file_exists($plugindir . '/styles.css')) {
             $stylesheets[] = 'styles.css';
@@ -787,12 +814,6 @@ class default_questiontype {
         if (file_exists($plugindir . '/styles.php')) {
             $stylesheets[] = 'styles.php';
         }
-        if (file_exists($plugindir . '/script.js')) {
-            require_js($baseurl . '/script.js');
-        }
-        if (file_exists($plugindir . '/script.php')) {
-            require_js($baseurl . '/script.php');
-        }
         $contributions = array();
         foreach ($stylesheets as $stylesheet) {
             $contributions[] = '<link rel="stylesheet" type="text/css" href="' .
@@ -853,7 +874,10 @@ class default_questiontype {
             $grade .= $question->maxgrade;
         }
 
-        $comment = stripslashes($state->manualcomment);
+        $formatoptions = new stdClass;
+        $formatoptions->para = false;
+        $comment = format_text(stripslashes($state->manualcomment), FORMAT_HTML,
+                $formatoptions, $cmoptions->course);
         $commentlink = '';
 
         if (!empty($options->questioncommentlink)) {
@@ -904,7 +928,8 @@ class default_questiontype {
 
         if (!empty($cmoptions->thispageurl)) {
         /// The module allow editing in the same window, print an ordinary link.
-            return '<a href="' . $CFG->wwwroot . $linkurl . '&amp;returnurl=' . urlencode($cmoptions->thispageurl) .
+            return '<a href="' . $CFG->wwwroot . $linkurl . '&amp;returnurl=' .
+                    urlencode($cmoptions->thispageurl . '#q' . $question->id) .
                     '" title="' . $stredit . '">' . $linktext . '</a>';
         } else {
         /// We have to edit in a pop-up.
@@ -919,76 +944,80 @@ class default_questiontype {
      * Used by print_question()
      */
     function history($question, $state, $number, $cmoptions, $options) {
-        $history = '';
-        if(isset($options->history) and $options->history) {
-            if ($options->history == 'all') {
-                // show all states
-                $states = get_records_select('question_states', "attempt = '$state->attempt' AND question = '$question->id' AND event > '0'", 'seq_number ASC');
-            } else {
-                // show only graded states
-                $states = get_records_select('question_states', "attempt = '$state->attempt' AND question = '$question->id' AND event IN (".QUESTION_EVENTS_GRADED.")", 'seq_number ASC');
-            }
-            if (count($states) > 1) {
-                $strreviewquestion = get_string('reviewresponse', 'quiz');
-                $table = new stdClass;
-                $table->width = '100%';
-                if ($options->scores) {
-                    $table->head  = array (
-                                           get_string('numberabbr', 'quiz'),
-                                           get_string('action', 'quiz'),
-                                           get_string('response', 'quiz'),
-                                           get_string('time'),
-                                           get_string('score', 'quiz'),
-                                           //get_string('penalty', 'quiz'),
-                                           get_string('grade', 'quiz'),
-                                           );
-                } else {
-                    $table->head  = array (
-                                           get_string('numberabbr', 'quiz'),
-                                           get_string('action', 'quiz'),
-                                           get_string('response', 'quiz'),
-                                           get_string('time'),
-                                           );
-                }
-
-                foreach ($states as $st) {
-                    $st->responses[''] = $st->answer;
-                    $this->restore_session_and_responses($question, $st);
-                    $b = ($state->id == $st->id) ? '<b>' : '';
-                    $be = ($state->id == $st->id) ? '</b>' : '';
-                    if ($state->id == $st->id) {
-                        $link = '<b>'.$st->seq_number.'</b>';
-                    } else {
-                        if(isset($options->questionreviewlink)) {
-                            $link = link_to_popup_window ($options->questionreviewlink.'?state='.$st->id.'&amp;number='.$number,
-                             'reviewquestion', $st->seq_number, 450, 650, $strreviewquestion, 'none', true);
-                        } else {
-                            $link = $st->seq_number;
-                        }
-                    }
-                    if ($options->scores) {
-                        $table->data[] = array (
-                                                $link,
-                                                $b.get_string('event'.$st->event, 'quiz').$be,
-                                                $b.$this->response_summary($question, $st).$be,
-                                                $b.userdate($st->timestamp, get_string('timestr', 'quiz')).$be,
-                                                $b.round($st->raw_grade, $cmoptions->decimalpoints).$be,
-                                                //$b.round($st->penalty, $cmoptions->decimalpoints).$be,
-                                                $b.round($st->grade, $cmoptions->decimalpoints).$be
-                                                );
-                    } else {
-                        $table->data[] = array (
-                                                $link,
-                                                $b.get_string('event'.$st->event, 'quiz').$be,
-                                                $b.$this->response_summary($question, $st).$be,
-                                                $b.userdate($st->timestamp, get_string('timestr', 'quiz')).$be,
-                                                );
-                    }
-                }
-                $history = print_table($table, true);
-            }
+        if (empty($options->history)) {
+            return '';
         }
-        return $history;
+
+        if (isset($question->randomquestionid)) {
+            $qid = $question->randomquestionid;
+            $randomprefix = 'random' . $question->id . '-';
+        } else {
+            $qid = $question->id;
+            $randomprefix = '';
+        }
+        if ($options->history == 'all') {
+            $eventtest = 'event > 0';
+        } else {
+            $eventtest = 'event IN (' . QUESTION_EVENTS_GRADED . ')';
+        }
+        $states = get_records_select('question_states',
+                'attempt = ' . $state->attempt . ' AND question = ' . $qid .
+                ' AND ' . $eventtest, 'seq_number ASC');
+        if (count($states) <= 1) {
+            return '';
+        }
+
+        $strreviewquestion = get_string('reviewresponse', 'quiz');
+        $table = new stdClass;
+        $table->width = '100%';
+        $table->head  = array (
+            get_string('numberabbr', 'quiz'),
+            get_string('action', 'quiz'),
+            get_string('response', 'quiz'),
+            get_string('time'),
+        );
+        if ($options->scores) {
+            $table->head[] = get_string('score', 'quiz');
+            $table->head[] = get_string('grade', 'quiz');
+        }
+
+        foreach ($states as $st) {
+            if ($randomprefix && strpos($st->answer, $randomprefix) === 0) {
+                $st->answer = substr($st->answer, strlen($randomprefix));
+            }
+            $st->responses[''] = $st->answer;
+            $this->restore_session_and_responses($question, $st);
+
+            if ($state->id == $st->id) {
+                $link = '<b>' . $st->seq_number . '</b>';
+            } else if (isset($options->questionreviewlink)) {
+                $link = link_to_popup_window($options->questionreviewlink.'?state='.$st->id.'&amp;number='.$number,
+                        'reviewquestion', $st->seq_number, 450, 650, $strreviewquestion, 'none', true);
+            } else {
+                $link = $st->seq_number;
+            }
+
+            if ($state->id == $st->id) {
+                $b = '<b>';
+                $be = '</b>';
+            } else {
+                $b = '';
+                $be = '';
+            }
+
+            $data = array (
+                $link,
+                $b.get_string('event'.$st->event, 'quiz').$be,
+                $b.$this->response_summary($question, $st).$be,
+                $b.userdate($st->timestamp, get_string('timestr', 'quiz')).$be,
+            );
+            if ($options->scores) {
+                $data[] = $b.round($st->raw_grade, $cmoptions->decimalpoints).$be;
+                $data[] = $b.round($st->grade, $cmoptions->decimalpoints).$be;
+            }
+            $table->data[] = $data;
+        }
+        return print_table($table, true);
     }
 
 
@@ -1054,7 +1083,7 @@ class default_questiontype {
                     // print info about new penalty
                     // penalty is relevant only if the answer is not correct and further attempts are possible
                     if (($state->last_graded->raw_grade < $question->maxgrade / 1.01)
-                                and (QUESTION_EVENTCLOSEANDGRADE !== $state->event)) {
+                                and (QUESTION_EVENTCLOSEANDGRADE != $state->event)) {
 
                         if ('' !== $state->last_graded->penalty && ((float)$state->last_graded->penalty) > 0.0) {
                             // A penalty was applied so display it
@@ -1154,14 +1183,14 @@ class default_questiontype {
     * @param object $state   The state whose responses are to be summarized
     * @param int $length     The maximum length of the returned string
     */
-    function response_summary($question, $state, $length=80) {
+    function response_summary($question, $state, $length = 80) {
         // This should almost certainly be overridden
         $responses = $this->get_actual_response($question, $state);
         if (empty($responses) || !is_array($responses)) {
             $responses = array();
         }
         if (is_array($responses)) {
-            $responses = implode(',', array_map('s', $responses));
+            $responses = implode(', ', array_map('s', $responses));
         }
         return shorten_text($responses, $length);
     }
@@ -1678,6 +1707,88 @@ class default_questiontype {
         return $state->answer;
     }
 
+/// IMPORT/EXPORT FUNCTIONS /////////////////
+
+    /*
+     * Imports question from the Moodle XML format
+     *
+     * Imports question using information from extra_question_fields function
+     * If some of you fields contains id's you'll need to reimplement this
+     */
+    function import_from_xml($data, $question, $format, $extra=null) {
+        $question_type = $data['@']['type'];
+        if ($question_type != $this->name()) {
+            return false;
+        }
+
+        $extraquestionfields = $this->extra_question_fields();
+        if (!is_array($extraquestionfields)) {
+            return false;
+        }
+
+        //omit table name
+        array_shift($extraquestionfields);
+        $qo = $format->import_headers($data);
+        $qo->qtype = $question_type;
+
+        foreach ($extraquestionfields as $field) {
+            $qo->$field = $format->getpath($data, array('#',$field,0,'#'), $qo->$field);
+        }
+
+        // run through the answers
+        $answers = $data['#']['answer'];
+        $a_count = 0;
+        $extraasnwersfields = $this->extra_answer_fields();
+        if (is_array($extraasnwersfields)) {
+            //TODO import the answers, with any extra data.
+        } else {
+            foreach ($answers as $answer) {
+                $ans = $format->import_answer($answer);
+                $qo->answer[$a_count] = $ans->answer;
+                $qo->fraction[$a_count] = $ans->fraction;
+                $qo->feedback[$a_count] = $ans->feedback;
+                ++$a_count;
+            }
+        }
+        return $qo;
+    }
+
+    /*
+     * Export question to the Moodle XML format
+     *
+     * Export question using information from extra_question_fields function
+     * If some of you fields contains id's you'll need to reimplement this
+     */
+    function export_to_xml($question, $format, $extra=null) {
+        $extraquestionfields = $this->extra_question_fields();
+        if (!is_array($extraquestionfields)) {
+            return false;
+        }
+
+        //omit table name
+        array_shift($extraquestionfields);
+        $expout='';
+        foreach ($extraquestionfields as $field) {
+            $expout .= "    <$field>{$question->options->$field}</$field>\n";
+        }
+
+        $extraasnwersfields = $this->extra_answer_fields();
+        if (is_array($extraasnwersfields)) {
+            //TODO export answers with any extra data
+        } else {
+            foreach ($question->options->answers as $answer) {
+                $percent = 100 * $answer->fraction;
+                $expout .= "    <answer fraction=\"$percent\">\n";
+                $expout .= $format->writetext($answer->answer, 3, false);
+                $expout .= "      <feedback>\n";
+                $expout .= $format->writetext($answer->feedback, 4, false);
+                $expout .= "      </feedback>\n";
+                $expout .= "    </answer>\n";
+            }
+        }
+        return $expout;
+    }
+
     /**
      * Abstract function implemented by each question type. It runs all the code
      * required to set up and save a question of any type for testing purposes.
