@@ -30,13 +30,15 @@ require_once 'Zend/Search/Lucene/Index/SegmentInfo.php';
 require_once 'Zend/Search/Lucene/Index/SegmentMerger.php';
 
 /** Zend_Search_Lucene_LockManager */
-if (@$CFG->block_search_softlock){
-    require_once "Zend/Search/Lucene/SoftLockManager.php";
+if (!empty($CFG->block_search_softlock)){
+    require_once 'Zend/Search/Lucene/SoftLockManager.php';
 } else {
-    require_once "Zend/Search/Lucene/LockManager.php";
+    require_once 'Zend/Search/Lucene/LockManager.php';
 }
 
 
+
+
 /**
  * @category   Zend
  * @package    Zend_Search_Lucene
