@@ -1,4 +1,4 @@
-<?PHP // $Id: index.php,v 1.194.2.18 2008/12/01 20:46:13 skodak Exp $
+<?PHP // $Id: index.php,v 1.194.2.23 2010/02/04 04:37:31 rwijaya Exp $
 
 //  Lists all the users within a given course
 
@@ -140,8 +140,7 @@
         $currentgroup  = NULL;
     }
 
-    $isseparategroups = ($course->groupmode == SEPARATEGROUPS and $course->groupmodeforce and
-                         !has_capability('moodle/site:accessallgroups', $context));
+    $isseparategroups = ($course->groupmode == SEPARATEGROUPS and !has_capability('moodle/site:accessallgroups', $context));
 
     if ($isseparategroups and (!$currentgroup) ) {
         $navlinks = array();
@@ -446,7 +445,7 @@
     if (!empty($search)) {
         $LIKE = sql_ilike();
         $fullname  = sql_fullname('u.firstname','u.lastname');
-        $wheresearch .= ' AND ('. $fullname .' '. $LIKE .'\'%'. $search .'%\' OR email '. $LIKE .'\'%'. $search .'%\' OR idnumber '.$LIKE.' \'%'.$search.'%\') ';
+        $wheresearch .= ' AND ('. $fullname .' '. $LIKE .' \'%'. $search .'%\' OR email '. $LIKE .' \'%'. $search .'%\' OR idnumber '.$LIKE.' \'%'.$search.'%\') ';
 
     }
 
@@ -680,7 +679,7 @@
 
 
         if ($userlist)  {
-            $usersprinted = array();
+            $usersprinted = array();            
             while ($user = rs_fetch_next_record($userlist)) {
                 if (in_array($user->id, $usersprinted)) { /// Prevent duplicates by r.hidden - MDL-13935
                     continue;
@@ -718,11 +717,19 @@
                 } else {
                     $usercontext = $user->context;
                 }
+                
+                $contextcanviewdetails = has_capability('moodle/user:viewdetails', $context);
+                $usercontextcanviewdetails = has_capability('moodle/user:viewdetails', $usercontext);
 
-                if ($piclink = ($USER->id == $user->id || has_capability('moodle/user:viewdetails', $context) || has_capability('moodle/user:viewdetails', $usercontext))) {
-                    $profilelink = '<strong><a href="'.$CFG->wwwroot.'/user/view.php?id='.$user->id.'&amp;course='.$course->id.'">'.fullname($user).'</a></strong>';
+                if ($piclink = ($USER->id == $user->id || $contextcanviewdetails || $usercontextcanviewdetails)) {
+                    if ($usercontextcanviewdetails) {
+                        $canviewfullname = has_capability('moodle/site:viewfullnames', $usercontext);
+                    } else {
+                        $canviewfullname = has_capability('moodle/site:viewfullnames', $context);
+                    } 
+                    $profilelink = '<strong><a href="'.$CFG->wwwroot.'/user/view.php?id='.$user->id.'&amp;course='.$course->id.'">'.fullname($user, $canviewfullname).'</a></strong>';
                 } else {
-                    $profilelink = '<strong>'.fullname($user).'</strong>';
+                    $profilelink = '<strong>'.fullname($user, has_capability('moodle/site:viewfullnames', $context)).'</strong>';
                 }
 
                 $data = array (
@@ -788,8 +795,8 @@
 
     }
 
-    if ($bulkoperations && $totalcount > ($perpage*3)) {
-        echo '<form action="index.php"><div><input type="hidden" name="id" value="'.$course->id.'" />'.get_string('search').':&nbsp;'."\n";
+    if (has_capability('moodle/site:viewparticipants', $context) && $totalcount > ($perpage*3)) {
+        echo '<form action="index.php" class="searchform"><div><input type="hidden" name="id" value="'.$course->id.'" />'.get_string('search').':&nbsp;'."\n";
         echo '<input type="text" name="search" value="'.s($search).'" />&nbsp;<input type="submit" value="'.get_string('search').'" /></div></form>'."\n";
     }
 
