@@ -1,4 +1,4 @@
-<?PHP // $Id: view.php,v 1.168.2.24 2008/12/01 22:06:55 skodak Exp $
+<?PHP // $Id: view.php,v 1.168.2.30 2010/03/18 22:54:28 skodak Exp $
 
 //  Display profile for a particular user
 
@@ -89,7 +89,7 @@
             }
 
             if (!has_capability('moodle/course:view', $coursecontext, $user->id, false)) {
-                if (has_capability('moodle/course:view', $coursecontext)) {
+                if (has_capability('moodle/role:assign', $coursecontext)) {
                     $navlinks[] = array('name' => $fullname, 'link' => null, 'type' => 'misc');
                     $navigation = build_navigation($navlinks);
                     print_header("$strpersonalprofile: ", "$strpersonalprofile: ", $navigation, "", "", true, "&nbsp;", navmenu($course));
@@ -260,11 +260,11 @@
         $emailswitch = '';
 
         if (has_capability('moodle/course:useremail', $coursecontext) or $currentuser) {   /// Can use the enable/disable email stuff
-            if (!empty($enable)) {     /// Recieved a parameter to enable the email address
+            if (!empty($enable) and confirm_sesskey()) {     /// Recieved a parameter to enable the email address
                 set_field('user', 'emailstop', 0, 'id', $user->id);
                 $user->emailstop = 0;
             }
-            if (!empty($disable)) {     /// Recieved a parameter to disable the email address
+            if (!empty($disable) and confirm_sesskey()) {     /// Recieved a parameter to disable the email address
                 set_field('user', 'emailstop', 1, 'id', $user->id);
                 $user->emailstop = 1;
             }
@@ -283,7 +283,7 @@
                 $switchpix   = 'email.gif';
             }
             $emailswitch = "&nbsp;<a title=\"$switchclick\" ".
-                           "href=\"view.php?id=$user->id&amp;course=$course->id&amp;$switchparam=1\">".
+                           "href=\"view.php?id=$user->id&amp;course=$course->id&amp;$switchparam=1&amp;sesskey=".sesskey()."\">".
                            "<img src=\"$CFG->pixpath/t/$switchpix\" alt=\"$switchclick\" /></a>";
 
         } else if ($currentuser) {         /// Can only re-enable an email this way
@@ -293,7 +293,7 @@
                 $switchclick = get_string('emailenableclick');
 
                 $emailswitch = "&nbsp;(<a title=\"$switchclick\" ".
-                               "href=\"view.php?id=$user->id&amp;course=$course->id&amp;enable=1\">$switchtitle</a>)";
+                               "href=\"view.php?id=$user->id&amp;course=$course->id&amp;enable=1&amp;sesskey=".sesskey()."\">$switchtitle</a>)";
             }
         }
 
@@ -332,7 +332,7 @@
 
 
     if (!isset($hiddenfields['mycourses'])) {
-        if ($mycourses = get_my_courses($user->id, null, null, false, 21)) {
+        if ($mycourses = get_my_courses($user->id, 'visible DESC,sortorder ASC', null, false, 21)) {
             $shown=0;
             $courselisting = '';
             foreach ($mycourses as $mycourse) {
@@ -361,7 +361,14 @@
             print_row(get_string('courses').':', rtrim($courselisting,', '));
         }
     }
-
+    if (!isset($hiddenfields['firstaccess'])) {
+        if ($user->firstaccess) {
+            $datestring = userdate($user->firstaccess)."&nbsp; (".format_time(time() - $user->firstaccess).")";
+        } else {
+            $datestring = get_string("never");
+        }
+        print_row(get_string("firstaccess").":", $datestring);
+    }
     if (!isset($hiddenfields['lastaccess'])) {
         if ($user->lastaccess) {
             $datestring = userdate($user->lastaccess)."&nbsp; (".format_time(time() - $user->lastaccess).")";
@@ -377,15 +384,16 @@
     }
 
 /// Printing groups
-    $isseparategroups = ($course->groupmode == SEPARATEGROUPS and $course->groupmodeforce and
-                             !has_capability('moodle/site:accessallgroups', $coursecontext));
-    if (!$isseparategroups){
-        if ($usergroups = groups_get_all_groups($course->id, $user->id)){
-            $groupstr = '';
-            foreach ($usergroups as $group){
-                $groupstr .= ' <a href="'.$CFG->wwwroot.'/user/index.php?id='.$course->id.'&amp;group='.$group->id.'">'.format_string($group->name).'</a>,';
+    if (!isset($hiddenfields['groups'])) {
+        $isseparategroups = ($course->groupmode == SEPARATEGROUPS and !has_capability('moodle/site:accessallgroups', $coursecontext));
+        if (!$isseparategroups){
+            if ($usergroups = groups_get_all_groups($course->id, $user->id)){
+                $groupstr = '';
+                foreach ($usergroups as $group){
+                    $groupstr .= ' <a href="'.$CFG->wwwroot.'/user/index.php?id='.$course->id.'&amp;group='.$group->id.'">'.format_string($group->name).'</a>,';
+                }
+                print_row(get_string("group").":", rtrim($groupstr, ', '));
             }
-            print_row(get_string("group").":", rtrim($groupstr, ', '));
         }
     }
 /// End of printing groups
